@@ -1,5 +1,5 @@
 /*
- * $Id: DefaultExceptionStrategyTestCase.java 19651 2010-09-14 15:22:50Z dirk.olmes $
+ * $Id: DefaultExceptionStrategyTestCase.java 22772 2011-08-27 15:20:15Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,20 +10,25 @@
 
 package org.mule;
 
+import static org.junit.Assert.assertEquals;
+
 import org.mule.api.MuleContext;
 import org.mule.api.context.notification.ExceptionNotificationListener;
 import org.mule.api.context.notification.ServerNotification;
 import org.mule.context.notification.ExceptionNotification;
 import org.mule.exception.DefaultSystemExceptionStrategy;
-import org.mule.tck.AbstractMuleTestCase;
+import org.mule.tck.junit4.AbstractMuleContextTestCase;
 
-import edu.emory.mathcs.backport.java.util.concurrent.CountDownLatch;
-import edu.emory.mathcs.backport.java.util.concurrent.TimeUnit;
-import edu.emory.mathcs.backport.java.util.concurrent.atomic.AtomicInteger;
+import java.util.concurrent.CountDownLatch;
+import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicInteger;
 
-public class DefaultExceptionStrategyTestCase extends AbstractMuleTestCase
+import org.junit.Test;
+
+public class DefaultExceptionStrategyTestCase extends AbstractMuleContextTestCase
 {
     // MULE-1404
+    @Test
     public void testExceptions() throws Exception
     {
         InstrumentedExceptionStrategy strategy = new InstrumentedExceptionStrategy(muleContext);
@@ -33,6 +38,7 @@ public class DefaultExceptionStrategyTestCase extends AbstractMuleTestCase
     }
 
     // MULE-1627
+    @Test
     public void testExceptionNotifications() throws Exception
     {
         final CountDownLatch latch = new CountDownLatch(1);
@@ -71,7 +77,7 @@ public class DefaultExceptionStrategyTestCase extends AbstractMuleTestCase
         {
             super(muleContext);
         }
-        
+
         @Override
         public void handleException(Exception exception)
         {
