@@ -1,5 +1,5 @@
 /*
- * $Id: DefaultMuleContext.java 22816 2011-09-01 22:02:55Z mike.schilling $
+ * $Id: DefaultMuleContext.java 24405 2012-05-25 14:28:45Z svacas $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -7,6 +7,7 @@
  * license, a copy of which has been included with this distribution in the
  * LICENSE.txt file.
  */
+
 package org.mule;
 
 import org.mule.api.MessagingException;
@@ -14,6 +15,7 @@ import org.mule.api.MuleContext;
 import org.mule.api.MuleEvent;
 import org.mule.api.MuleException;
 import org.mule.api.MuleRuntimeException;
+import org.mule.api.SingleResourceTransactionFactoryManager;
 import org.mule.api.client.LocalMuleClient;
 import org.mule.api.config.MuleConfiguration;
 import org.mule.api.config.MuleProperties;
@@ -22,7 +24,9 @@ import org.mule.api.context.MuleContextAware;
 import org.mule.api.context.WorkManager;
 import org.mule.api.context.notification.ServerNotification;
 import org.mule.api.context.notification.ServerNotificationListener;
+import org.mule.api.el.ExpressionLanguage;
 import org.mule.api.endpoint.EndpointFactory;
+import org.mule.api.exception.MessagingExceptionHandler;
 import org.mule.api.exception.RollbackSourceCallback;
 import org.mule.api.exception.SystemExceptionHandler;
 import org.mule.api.expression.ExpressionManager;
@@ -44,6 +48,7 @@ import org.mule.config.i18n.CoreMessages;
 import org.mule.context.notification.MuleContextNotification;
 import org.mule.context.notification.NotificationException;
 import org.mule.context.notification.ServerNotificationManager;
+import org.mule.exception.DefaultMessagingExceptionStrategy;
 import org.mule.exception.DefaultSystemExceptionStrategy;
 import org.mule.expression.DefaultExpressionManager;
 import org.mule.lifecycle.MuleContextLifecycleManager;
@@ -54,9 +59,11 @@ import org.mule.transport.DefaultPollingController;
 import org.mule.transport.PollingController;
 import org.mule.util.ApplicationShutdownSplashScreen;
 import org.mule.util.ApplicationStartupSplashScreen;
+import org.mule.util.JdkVersionUtils;
 import org.mule.util.ServerShutdownSplashScreen;
 import org.mule.util.ServerStartupSplashScreen;
 import org.mule.util.SplashScreen;
+import org.mule.util.SystemUtils;
 import org.mule.util.UUID;
 import org.mule.util.queue.QueueManager;
 
@@ -131,6 +138,10 @@ public class DefaultMuleContext implements MuleContext
 
     private Map<QName, Set<Object>> configurationAnnotations;
 
+    private SingleResourceTransactionFactoryManager singleResourceTransactionFactoryManager = new SingleResourceTransactionFactoryManager();
+
+    private TransactionManager transactionManager;
+
     public DefaultMuleContext(MuleConfiguration config,
                               WorkManager workManager,
                               WorkListener workListener,
@@ -177,6 +188,16 @@ public class DefaultMuleContext implements MuleContext
         {
             throw new MuleRuntimeException(CoreMessages.objectIsNull("workManager"));
         }
+        
+        try
+        {
+        	JdkVersionUtils.validateJdk();
+        }
+        catch (RuntimeException e)
+        {
+        	throw new InitialisationException(CoreMessages.invalidJdk(SystemUtils.JAVA_VERSION, 
+        			SystemUtils.JAVA_VENDOR, JdkVersionUtils.getSupportedJdks()), this);
+        }
 
         try
         {
@@ -196,6 +217,11 @@ public class DefaultMuleContext implements MuleContext
             fireNotification(new MuleContextNotification(this, MuleContextNotification.CONTEXT_INITIALISING));
             getLifecycleManager().fireLifecycle(Initialisable.PHASE_NAME);
 
+            if (expressionManager instanceof Initialisable)
+            {
+                ((Initialisable) expressionManager).initialise();
+            }
+
             fireNotification(new MuleContextNotification(this, MuleContextNotification.CONTEXT_INITIALISED));
         }
         catch (Exception e)
@@ -280,6 +306,11 @@ public class DefaultMuleContext implements MuleContext
 
         notificationManager.dispose();
         workManager.dispose();
+        
+        if (expressionManager != null && expressionManager instanceof Disposable)
+        {
+            ((Disposable) expressionManager).dispose();
+        }
 
         if ((getStartDate() > 0) && logger.isInfoEnabled())
         {
@@ -500,7 +531,6 @@ public class DefaultMuleContext implements MuleContext
     {
 
         return config;
-        //return (MuleConfiguration) getRegistry().lookupObject(MuleProperties.OBJECT_MULE_CONFIGURATION);
     }
 
     public ServerNotificationManager getNotificationManager()
@@ -529,27 +559,30 @@ public class DefaultMuleContext implements MuleContext
      */
     public TransactionManager getTransactionManager()
     {
-        TransactionManager transactionManager = (TransactionManager) registryBroker.lookupObject(MuleProperties.OBJECT_TRANSACTION_MANAGER);
         if (transactionManager == null)
         {
-            Collection temp = registryBroker.lookupObjects(TransactionManagerFactory.class);
-            if (temp.size() > 0)
+            transactionManager = (TransactionManager) registryBroker.lookupObject(MuleProperties.OBJECT_TRANSACTION_MANAGER);
+            if (transactionManager == null)
             {
-                try
-                {
-                    transactionManager = (((TransactionManagerFactory) temp.iterator().next()).create(config));
-                }
-                catch (Exception e)
-                {
-                    throw new MuleRuntimeException(CoreMessages.failedToCreate("transaction manager"), e);
-                }
-            }
-            else
-            {
-                temp = registryBroker.lookupObjects(TransactionManager.class);
+                Collection temp = registryBroker.lookupObjects(TransactionManagerFactory.class);
                 if (temp.size() > 0)
                 {
-                    transactionManager = (((TransactionManager) temp.iterator().next()));
+                    try
+                    {
+                        transactionManager = (((TransactionManagerFactory) temp.iterator().next()).create(config));
+                    }
+                    catch (Exception e)
+                    {
+                        throw new MuleRuntimeException(CoreMessages.failedToCreate("transaction manager"), e);
+                    }
+                }
+                else
+                {
+                    temp = registryBroker.lookupObjects(TransactionManager.class);
+                    if (temp.size() > 0)
+                    {
+                        transactionManager = (((TransactionManager) temp.iterator().next()));
+                    }
                 }
             }
         }
@@ -664,19 +697,19 @@ public class DefaultMuleContext implements MuleContext
         if (e instanceof MessagingException)
         {
             MuleEvent event = ((MessagingException) e).getEvent();
-            event.getFlowConstruct().getExceptionListener().handleException(e, event, rollbackMethod);
+            event.getFlowConstruct().getExceptionListener().handleException(e, event);
         }
         else
         {
             getExceptionListener().handleException(e, rollbackMethod);
         }
     }
-    
+
     public void handleException(Exception e)
     {
         handleException(e, null);
     }
-    
+
     public SystemExceptionHandler getExceptionListener()
     {
         return exceptionListener;
@@ -740,4 +773,57 @@ public class DefaultMuleContext implements MuleContext
     {
         return configurationAnnotations;
     }
+
+    @Override
+    public MessagingExceptionHandler getDefaultExceptionStrategy()
+    {
+        MessagingExceptionHandler defaultExceptionStrategy;
+        if (config.getDefaultExceptionStrategyName() != null)
+        {
+            defaultExceptionStrategy = getRegistry().lookupObject(config.getDefaultExceptionStrategyName());
+            if (defaultExceptionStrategy == null)
+            {
+                throw new MuleRuntimeException(CoreMessages.createStaticMessage(String.format("No global exception strategy named %s",config.getDefaultExceptionStrategyName())));
+            }
+        }
+        else
+        {
+            defaultExceptionStrategy = new DefaultMessagingExceptionStrategy(this);
+        }
+        return defaultExceptionStrategy;
+    }
+
+    @Override
+    public SingleResourceTransactionFactoryManager getTransactionFactoryManager()
+    {
+        return this.singleResourceTransactionFactoryManager;
+    }
+
+    @Override
+    public DataTypeConversionResolver getDataTypeConverterResolver()
+    {
+        DataTypeConversionResolver dataTypeConversionResolver = getRegistry().lookupObject(MuleProperties.OBJECT_CONVERTER_RESOLVER);
+        if (dataTypeConversionResolver == null)
+        {
+            dataTypeConversionResolver = new DynamicDataTypeConversionResolver(this);
+
+            try
+            {
+                getRegistry().registerObject(MuleProperties.OBJECT_CONVERTER_RESOLVER, dataTypeConversionResolver);
+            }
+            catch (RegistrationException e)
+            {
+                // Should not occur
+                throw new IllegalStateException(e);
+            }
+        }
+
+        return dataTypeConversionResolver;
+    }
+
+    @Override
+    public ExpressionLanguage getExpressionLanguage()
+    {
+        return registryBroker.lookupObject(MuleProperties.OBJECT_EXPRESSION_LANGUAGE);
+    }
 }
