@@ -1,5 +1,5 @@
 /*
- * $Id: DefaultMuleMessage.java 22870 2011-09-05 20:41:52Z dfeist $
+ * $Id: DefaultMuleMessage.java 24239 2012-04-07 15:02:40Z pablo.kraan $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -18,14 +18,17 @@ import org.mule.api.MuleMessage;
 import org.mule.api.MuleRuntimeException;
 import org.mule.api.ThreadSafeAccess;
 import org.mule.api.config.MuleProperties;
+import org.mule.api.transformer.Converter;
 import org.mule.api.transformer.DataType;
 import org.mule.api.transformer.MessageTransformer;
 import org.mule.api.transformer.Transformer;
 import org.mule.api.transformer.TransformerException;
+import org.mule.api.transformer.TransformerMessagingException;
 import org.mule.api.transport.OutputHandler;
 import org.mule.api.transport.PropertyScope;
 import org.mule.config.MuleManifest;
 import org.mule.config.i18n.CoreMessages;
+import org.mule.transformer.TransformerUtils;
 import org.mule.transformer.types.DataTypeFactory;
 import org.mule.transformer.types.MimeTypes;
 import org.mule.transport.NullPayload;
@@ -53,7 +56,6 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
-import java.util.concurrent.CopyOnWriteArrayList;
 import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.atomic.AtomicReference;
 
@@ -106,7 +108,6 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
      */
     private transient Map<String, DataHandler> outboundAttachments = new ConcurrentHashMap<String, DataHandler>();
 
-    private transient List<Integer> appliedTransformerHashCodes;
     private transient byte[] cache;
     protected transient MuleContext muleContext;
 
@@ -158,7 +159,6 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
                               MuleContext muleContext)
     {
         setMuleContext(muleContext);
-        initAppliedTransformerHashCodes();
 
         if (message instanceof MuleMessage)
         {
@@ -188,7 +188,6 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
         id = previous.getUniqueId();
         rootId = previous.getMessageRootId();
         setMuleContext(muleContext);
-        initAppliedTransformerHashCodes();
         setEncoding(previous.getEncoding());
 
         if (message instanceof MuleMessage)
@@ -209,19 +208,26 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
             setExceptionPayload(previous.getExceptionPayload());
         }
 
+        if (previous instanceof DefaultMuleMessage)
+        {
+            setInvocationProperties(((DefaultMuleMessage) previous).properties.invocationMap);
+            setSessionProperties(((DefaultMuleMessage) previous).properties.sessionMap);
+        }
+
         copyAttachments(previous);
 
         resetAccessControl();
     }
 
-    private void copyMessageProperties(MuleMessage muleMessage)
+    protected void copyMessageProperties(MuleMessage muleMessage)
     {
         // explicitly copy INBOUND message properties over. This cannot be done in the loop below
         Map<String, Object> inboundProperties =
                 ((DefaultMuleMessage) muleMessage).properties.getScopedProperties(PropertyScope.INBOUND);
         addInboundProperties(inboundProperties);
 
-        for (PropertyScope scope : PropertyScope.ALL_SCOPES)
+        for (PropertyScope scope : new PropertyScope[]{PropertyScope.INBOUND,
+            PropertyScope.OUTBOUND})
         {
             try
             {
@@ -288,11 +294,6 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
         muleContext = context;
     }
 
-    private void initAppliedTransformerHashCodes()
-    {
-        appliedTransformerHashCodes = new CopyOnWriteArrayList<Integer>();
-    }
-
     /**
      * {@inheritDoc}
      */
@@ -563,8 +564,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
         }
         catch (Exception e)
         {
-            // TODO Auto-generated catch block
-            return  "[Messaage could not be converted to string]";
+            return  "[Message could not be converted to string]";
         }
     }
 
@@ -580,8 +580,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
         }
         catch (Exception e)
         {
-            // TODO Auto-generated catch block
-            return  "[Messaage could not be converted to string]";
+            return  "[Message could not be converted to string]";
         }
     }
 
@@ -645,21 +644,7 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     public Set<String> getPropertyNames(PropertyScope scope)
     {
         assertAccess(READ);
-        if (PropertyScope.SESSION.equals(scope))
-        {
-            if (RequestContext.getEvent() != null)
-            {
-                return RequestContext.getEvent().getSession().getPropertyNamesAsSet();
-            }
-            else
-            {
-                return Collections.emptySet();
-            }
-        }
-        else
-        {
-            return properties.getScopedProperties(scope).keySet();
-        }
+        return properties.getScopedProperties(scope).keySet();
     }
 
     @Override
@@ -1328,7 +1313,6 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     public void release()
     {
         cache = null;
-        appliedTransformerHashCodes.clear();
     }
 
     /**
@@ -1352,10 +1336,9 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     @Override
     public void applyTransformers(MuleEvent event, List<? extends Transformer> transformers, Class<?> outputType) throws MuleException
     {
-        if (!transformers.isEmpty() && !appliedTransformerHashCodes.contains(transformers.hashCode()))
+        if (!transformers.isEmpty())
         {
             applyAllTransformers(event, transformers);
-            appliedTransformerHashCodes.add(transformers.hashCode());
         }
 
         if (null != outputType && !getPayload().getClass().isAssignableFrom(outputType))
@@ -1368,68 +1351,16 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     {
         if (!transformers.isEmpty())
         {
-            for (Transformer transformer : transformers)
+            for (int index = 0; index < transformers.size(); index++)
             {
-                if (getPayload() == null)
-                {
-                    if (transformer.isAcceptNull())
-                    {
-                        setPayload(NullPayload.getInstance());
-                        setDataType(null);
-                    }
-                    else
-                    {
-                        if (logger.isDebugEnabled())
-                        {
-                            logger.debug("Transformer " + transformer +
-                                    " doesn't support the null payload, exiting from transformer chain.");
-                        }
-                        break;
-                    }
-                }
+                Transformer transformer = transformers.get(index);
 
                 Class<?> srcCls = getPayload().getClass();
-                if (transformer.isSourceDataTypeSupported(DataTypeFactory.create(srcCls)))
+                DataType<?> originalSourceType = DataTypeFactory.create(srcCls);
+
+                if (transformer.isSourceDataTypeSupported(originalSourceType))
                 {
-                    Object result;
-                    if (transformer instanceof MessageTransformer)
-                    {
-                        result = ((MessageTransformer) transformer).transform(this, event);
-                    }
-                    else
-                    {
-                        result = transformer.transform(this);
-                    }
-                    // Update the RequestContext with the result of the transformation.
-                    RequestContext.internalRewriteEvent(this, false);
-
-                    if (originalPayload == null && muleContext.getConfiguration().isCacheMessageOriginalPayload())
-                    {
-                        originalPayload = payload;
-                    }
-
-                    if (result instanceof MuleMessage)
-                    {
-                        if (!result.equals(this))
-                        {
-                            // Only copy the payload and properties of mule message
-                            // transformer result if the message is a different
-                            // instance
-                            synchronized (this)
-                            {
-                                MuleMessage resultMessage = (MuleMessage) result;
-                                setPayload(resultMessage.getPayload());
-                                originalPayload = resultMessage.getOriginalPayload();
-                                copyMessageProperties(resultMessage);
-                                copyAttachments(resultMessage);
-                            }
-                        }
-                    }
-                    else
-                    {
-                        setPayload(result);
-                    }
-                    setDataType(transformer.getReturnDataType());
+                    transformMessage(event, transformer);
                 }
                 else
                 {
@@ -1437,7 +1368,28 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
                     {
                         logger.debug("Transformer " + transformer + " doesn't support the source payload: " + srcCls);
                     }
-                    if (!transformer.isIgnoreBadInput())
+
+                    if (useExtendedTransformations())
+                    {
+                        if (canSkipTransformer(transformers, index))
+                        {
+                            continue;
+                        }
+
+                        // Resolves implicit conversion if possible
+                        Transformer implicitTransformer = muleContext.getDataTypeConverterResolver().resolve(originalSourceType, transformer.getSourceDataTypes());
+
+                        if (implicitTransformer != null)
+                        {
+                            transformMessage(event, implicitTransformer);
+                            transformMessage(event, transformer);
+                        }
+                        else
+                        {
+                            throw new IllegalArgumentException("Cannot apply transformer " + transformer + " on source payload: " + srcCls);
+                        }
+                    }
+                    else if (!transformer.isIgnoreBadInput())
                     {
                         if (logger.isDebugEnabled())
                         {
@@ -1450,6 +1402,94 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
         }
     }
 
+    private boolean canSkipTransformer(List<? extends Transformer> transformers, int index)
+    {
+        Transformer transformer = transformers.get(index);
+
+        boolean skipConverter = false;
+
+        if (transformer instanceof Converter)
+        {
+            if (index == transformers.size() - 1)
+            {
+                try
+                {
+                    TransformerUtils.checkTransformerReturnClass(transformer, payload);
+                    skipConverter = true;
+                }
+                catch (TransformerException e)
+                {
+                    // Converter cannot be skipped
+                }
+            }
+            else
+            {
+                skipConverter= true;
+            }
+        }
+
+        if (skipConverter)
+        {
+            logger.debug("Skipping converter: " + transformer);
+        }
+
+        return skipConverter;
+    }
+
+    private boolean useExtendedTransformations()
+    {
+        boolean result = true;
+        if (muleContext != null && muleContext.getConfiguration() != null)
+        {
+            result = muleContext.getConfiguration().useExtendedTransformations();
+        }
+
+        return result;
+    }
+
+    private void transformMessage(MuleEvent event, Transformer transformer) throws TransformerMessagingException, TransformerException
+    {
+        Object result;
+        if (transformer instanceof MessageTransformer)
+        {
+            result = ((MessageTransformer) transformer).transform(this, event);
+        }
+        else
+        {
+            result = transformer.transform(this);
+        }
+        // Update the RequestContext with the result of the transformation.
+        RequestContext.internalRewriteEvent(this, false);
+
+        if (originalPayload == null && muleContext.getConfiguration().isCacheMessageOriginalPayload())
+        {
+            originalPayload = payload;
+        }
+
+        if (result instanceof MuleMessage)
+        {
+            if (!result.equals(this))
+            {
+                // Only copy the payload and properties of mule message
+                // transformer result if the message is a different
+                // instance
+                synchronized (this)
+                {
+                    MuleMessage resultMessage = (MuleMessage) result;
+                    setPayload(resultMessage.getPayload());
+                    originalPayload = resultMessage.getOriginalPayload();
+                    copyMessageProperties(resultMessage);
+                    copyAttachments(resultMessage);
+                }
+            }
+        }
+        else
+        {
+            setPayload(result);
+        }
+        setDataType(transformer.getReturnDataType());
+    }
+
     protected void setDataType(DataType<?> dt)
     {
         dataType = dt;
@@ -1742,7 +1782,6 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
     public void initAfterDeserialisation(MuleContext context) throws MuleException
     {
         this.muleContext = context;
-        initAppliedTransformerHashCodes();
     }
 
     @Override
@@ -1921,17 +1960,17 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
         newMessage.clearProperties(PropertyScope.INVOCATION);
         newMessage.clearProperties(PropertyScope.OUTBOUND);
 
-        for (String s : newInboundProperties.keySet())
+        for (Map.Entry<String, Object> s : newInboundProperties.entrySet())
         {
-            newMessage.setInboundProperty(s, newInboundProperties.get(s));
+            newMessage.setInboundProperty(s.getKey(), s.getValue());
         }
 
         newMessage.inboundAttachments.clear();
         newMessage.outboundAttachments.clear();
 
-        for (String s : attachments.keySet())
+        for (Map.Entry<String, DataHandler> s : attachments.entrySet())
         {
-            newMessage.addInboundAttachment(s, attachments.get(s));
+            newMessage.addInboundAttachment(s.getKey(), s.getValue());
         }
 
         newMessage.setCorrelationId(getCorrelationId());
@@ -1940,4 +1979,15 @@ public class DefaultMuleMessage implements MuleMessage, ThreadSafeAccess, Deseri
         newMessage.setReplyTo(getReplyTo());
         newMessage.setEncoding(getEncoding());
     }
+    
+    void setSessionProperties(Map<String, Object> sessionProperties)
+    {
+        properties.sessionMap = sessionProperties;
+    }
+
+    void setInvocationProperties(Map<String, Object> invocationProperties)
+    {
+        properties.invocationMap = invocationProperties;
+    }
+
 }
