@@ -1,5 +1,5 @@
 /*
- * $Id: Mule4412TestCase.java 20320 2010-11-24 15:03:31Z dfeist $
+ * $Id: Mule4412TestCase.java 22421 2011-07-15 05:05:06Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,21 +13,39 @@ package org.mule;
 import org.mule.api.MuleMessage;
 import org.mule.api.transport.PropertyScope;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.AbstractServiceAndFlowTestCase;
 import org.mule.test.filters.FilterCounter;
 
+import java.util.Arrays;
+import java.util.Collection;
+
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+
 /**
  * Test for MULE-4412 : selective-consumer filter is applied twice. We test that the
  * filter is only applied once in the positive case, plus make sure it doesn't get
  * filtered at all when the message does not meet the filter criteria
  */
-public class Mule4412TestCase extends FunctionalTestCase
+public class Mule4412TestCase extends AbstractServiceAndFlowTestCase
 {
     private int RECEIVE_TIMEOUT_MS = 3000;
-    
-    protected String getConfigResources()
+
+    @Parameters
+    public static Collection<Object[]> parameters()
     {
-        return "mule-4412.xml";
+        return Arrays.asList(new Object[][]{{ConfigVariant.SERVICE, "mule-4412-service.xml"},
+            {ConfigVariant.FLOW, "mule-4412-flow.xml"}});
+    }
+
+    public Mule4412TestCase(ConfigVariant variant, String configResources)
+    {
+        super(variant, configResources);
     }
 
     @Override
@@ -48,9 +66,10 @@ public class Mule4412TestCase extends FunctionalTestCase
 
     /**
      * Make sure that the message only gets filtered once
-     * 
+     *
      * @throws Exception
      */
+    @Test
     public void testFilterOnce() throws Exception
     {
         DefaultMuleMessage msg = new DefaultMuleMessage(TEST_MESSAGE, muleContext);
@@ -71,9 +90,10 @@ public class Mule4412TestCase extends FunctionalTestCase
 
     /**
      * Make sure the message does not get filtered when the property key is incorrect
-     * 
+     *
      * @throws Exception
      */
+    @Test
     public void testWrongPropertyKey() throws Exception
     {
         DefaultMuleMessage msg = new DefaultMuleMessage(TEST_MESSAGE, muleContext);
@@ -88,9 +108,10 @@ public class Mule4412TestCase extends FunctionalTestCase
     /**
      * Make sure the message does not get filtered when the property value is not as
      * expected
-     * 
+     *
      * @throws Exception
      */
+    @Test
     public void testWrongPropertyValue() throws Exception
     {
         DefaultMuleMessage msg = new DefaultMuleMessage(TEST_MESSAGE, muleContext);
@@ -105,9 +126,10 @@ public class Mule4412TestCase extends FunctionalTestCase
     /**
      * Make sure the message does not get filtered at all when the expected property
      * is not defined
-     * 
+     *
      * @throws Exception
      */
+    @Test
     public void testNoProperty() throws Exception
     {
         DefaultMuleMessage msg = new DefaultMuleMessage(TEST_MESSAGE, muleContext);
