@@ -1,5 +1,5 @@
 /*
- * $Id: NamedObject.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id: NamedObject.java 22039 2011-05-30 19:12:17Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -7,21 +7,18 @@
  * license, a copy of which has been included with this distribution in the
  * LICENSE.txt file.
  */
+
 package org.mule.api;
 
 /**
- * Adds {@link #getName} and {@link #setName} methods to an object
+ * Adds {@link #getName} method to an object
  */
 public interface NamedObject
 {
-    /**
-     * Sets the name of the object
-     * @param name the name of the object
-     */
-    void setName(String name);
 
     /**
      * Gets the name of the object
+     * 
      * @return the name of the object
      */
     String getName();
