@@ -1,5 +1,5 @@
 /*
- * $Id: Agent.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: Agent.java 22048 2011-05-31 14:39:03Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,7 +10,7 @@
 
 package org.mule.api.agent;
 
-import org.mule.api.NamedObject;
+import org.mule.api.NameableObject;
 import org.mule.api.lifecycle.Lifecycle;
 
 /**
@@ -18,7 +18,7 @@ import org.mule.api.lifecycle.Lifecycle;
  * destroyed along with the MuleContext itself. Agents can initialise or bind to
  * external services such as a Jmx server.
  */
-public interface Agent extends Lifecycle, NamedObject
+public interface Agent extends Lifecycle, NameableObject
 {
     /**
      * A description of the agent that gets displayed in the splash
