@@ -1,5 +1,5 @@
 /*
- * $Id: MuleProperties.java 22483 2011-07-21 05:41:39Z stephen.fenech $
+ * $Id: MuleProperties.java 24453 2012-05-29 20:12:25Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -40,6 +40,7 @@ public class MuleProperties
     // public static final String MULE_METHOD_PROPERTY = PROPERTY_PREFIX + "SERVICE_METHOD";
     public static final String MULE_IGNORE_METHOD_PROPERTY = PROPERTY_PREFIX + "IGNORE_METHOD";
     public static final String MULE_ENDPOINT_PROPERTY = PROPERTY_PREFIX + "ENDPOINT";
+    public static final String MULE_ROOT_MESSAGE_ID_PROPERTY = PROPERTY_PREFIX + "ROOT_MESSAGE_ID";
     public static final String MULE_ORIGINATING_ENDPOINT_PROPERTY = PROPERTY_PREFIX + "ORIGINATING_ENDPOINT";
     public static final String MULE_ERROR_CODE_PROPERTY = PROPERTY_PREFIX + "ERROR_CODE";
     public static final String MULE_REPLY_TO_PROPERTY = PROPERTY_PREFIX + "REPLYTO";
@@ -127,8 +128,11 @@ public class MuleProperties
     public static final String OBJECT_SECURITY_MANAGER = "_muleSecurityManager";
     public static final String OBJECT_TRANSACTION_MANAGER = "_muleTransactionManager";
     public static final String OBJECT_QUEUE_MANAGER = "_muleQueueManager";
-    public static final String OBJECT_STORE_DEFAULT_IN_MEMORY_NAME = "_defaultInMemoryQueueStore";
-    public static final String OBJECT_STORE_DEFAULT_PERSISTENT_NAME = "_defaultPersistentQueueStore";
+    public static final String OBJECT_STORE_DEFAULT_IN_MEMORY_NAME = "_defaultInMemoryObjectStore";
+    public static final String OBJECT_STORE_DEFAULT_PERSISTENT_NAME = "_defaultPersistentObjectStore";
+    public static final String QUEUE_STORE_DEFAULT_IN_MEMORY_NAME = "_defaultInMemoryQueueStore";
+    public static final String QUEUE_STORE_DEFAULT_PERSISTENT_NAME = "_defaultPersistentQueueStore";
+    public static final String DEFAULT_USER_OBJECT_STORE_NAME = "_defaultUserObjectStore";
     public static final String OBJECT_STORE_MANAGER = "_muleObjectStoreManager";
     public static final String OBJECT_STORE_SIMPLE_MEMORY_NAME = "_simpleMemoryQueueStore";
     public static final String OBJECT_STORE_FILE_NAME = "_fileQueueStore";
@@ -141,9 +145,12 @@ public class MuleProperties
     public static final String OBJECT_DEFAULT_MESSAGE_REQUESTER_THREADING_PROFILE = "_defaultMessageRequesterThreadingProfile";
     public static final String OBJECT_DEFAULT_MESSAGE_RECEIVER_THREADING_PROFILE = "_defaultMessageReceiverThreadingProfile";
     public static final String OBJECT_DEFAULT_SERVICE_THREADING_PROFILE = "_defaultServiceThreadingProfile";
+    public static final String OBJECT_DEFAULT_GLOBAL_EXCEPTION_STRATEGY = "_defaultGlobalExceptionStrategy";
     public static final String OBJECT_DEFAULT_RETRY_POLICY_TEMPLATE = "_defaultRetryPolicyTemplate";
     public static final String OBJECT_MULE_CONFIGURATION = "_muleConfiguration";
     public static final String OBJECT_MULE_NAMESPACE_MANAGER = "_muleNamespaceManager";
+    public static final String OBJECT_CONVERTER_RESOLVER = "_converterResolver";
+    public static final String OBJECT_EXPRESSION_LANGUAGE = "_muleExpressionLanguage";
 
     // Not currently used as these need to be instance variables of the MuleContext.
     public static final String OBJECT_WORK_MANAGER = "_muleWorkManager";
@@ -167,5 +174,4 @@ public class MuleProperties
     public static final String MULE_ENCODING_SYSTEM_PROPERTY = SYSTEM_PROPERTY_PREFIX + "encoding";
 
     public static final String CONTENT_TYPE_PROPERTY = "Content-Type";
-
 }
