@@ -1,5 +1,5 @@
 /*
- * $Id: ServerNotification.java 22396 2011-07-12 21:26:04Z mike.schilling $
+ * $Id: ServerNotification.java 24259 2012-04-15 23:27:45Z pablo.kraan $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -46,6 +46,7 @@ public abstract class ServerNotification extends EventObject implements MuleCont
     protected static final int ADMIN_EVENT_ACTION_START_RANGE = 600;
     protected static final int CONNECTION_EVENT_ACTION_START_RANGE = 700;
     protected static final int MESSAGE_EVENT_ACTION_START_RANGE = 800;
+    protected static final int MESSAGE_EVENT_END_ACTION_START_RANGE = 850;
     protected static final int SPACE_EVENT_ACTION_START_RANGE = 900;
     protected static final int REGISTRY_EVENT_ACTION_START_RANGE = 1000;
     protected static final int EXCEPTION_EVENT_ACTION_START_RANGE = 1100;
@@ -54,6 +55,7 @@ public abstract class ServerNotification extends EventObject implements MuleCont
     protected static final int COMPONENT_EVENT_ACTION_START_RANGE = 1400;
     protected static final int FLOW_CONSTRUCT_EVENT_ACTION_START_RANGE = 1500;
     protected static final int MESSAGE_PROCESSOR_EVENT_ACTION_START_RANGE = 1600;
+    protected static final int CLUSTER_NODE_EVENT_ACTION_START_RANGE = 1700;
 
     public static final int CUSTOM_EVENT_ACTION_START_RANGE = 100000;
 
