@@ -1,5 +1,5 @@
 /*
- * $Id: MessagingExceptionHandler.java 21892 2011-05-12 14:44:17Z pablo.kraan $
+ * $Id: MessagingExceptionHandler.java 23581 2012-01-05 15:46:21Z pablo.lagreca $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -11,12 +11,11 @@
 package org.mule.api.exception;
 
 import org.mule.api.MuleEvent;
-import org.mule.routing.filters.WildcardFilter;
 
 /**
  * Take some action when a messaging exception has occurred (i.e., there was a message in play when the exception occurred).
  */
-public interface MessagingExceptionHandler
+public interface MessagingExceptionHandler extends ExceptionHandler
 {
     /**
      * Take some action when a messaging exception has occurred (i.e., there was a message in play when the exception occurred).
@@ -26,24 +25,6 @@ public interface MessagingExceptionHandler
      * @return new event to route on to the rest of the flow, generally with ExceptionPayload set on the message
      */
     MuleEvent handleException(Exception exception, MuleEvent event);
-
-    /**
-     * Returns the filter that given an exception class will determine if a
-     * transaction should be committed or not.
-     *
-     * @return the exception filter configured for commit of transactions or
-     *         null if there is no filter.
-     */
-    WildcardFilter getCommitTxFilter();
-
-    /**
-     * Returns the filter that given an exception class will determine if a
-     * transaction should be rollbacked or not.
-     *
-     * @return the exception filter configured for rollback of transactions or
-     *         null if there is no filter.
-     */
-    WildcardFilter getRollbackTxFilter();
 }
 
 
