@@ -1,5 +1,5 @@
 /*
- * $Id: SecurityException.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: SecurityException.java 19739 2010-09-27 14:28:40Z tcarlson $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,7 +12,6 @@ package org.mule.api.security;
 
 import org.mule.api.MessagingException;
 import org.mule.api.MuleEvent;
-import org.mule.api.MuleMessage;
 import org.mule.config.i18n.Message;
 
 /**
@@ -20,29 +19,11 @@ import org.mule.config.i18n.Message;
  */
 public abstract class SecurityException extends MessagingException
 {
-    /**
-     * @deprecated use SecurityException(Message, MuleEvent)
-     */
-    @Deprecated
-    protected SecurityException(Message message, MuleMessage muleMessage)
-    {
-        super(message, muleMessage);
-    }
-
     protected SecurityException(Message message, MuleEvent event)
     {
         super(message, event);
     }
 
-    /**
-     * @deprecated use SecurityException(Message, MuleEvent, Throwable)
-     */
-    @Deprecated
-    protected SecurityException(Message message, MuleMessage muleMessage, Throwable cause)
-    {
-        super(message, muleMessage, cause);
-    }
-
     protected SecurityException(Message message, MuleEvent event, Throwable cause)
     {
         super(message, event, cause);
