@@ -1,5 +1,5 @@
 /*
- * $Id: UnauthorisedException.java 21251 2011-02-11 00:23:49Z dandiep $
+ * $Id: UnauthorisedException.java 22548 2011-07-24 10:38:33Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,10 +12,11 @@ package org.mule.api.security;
 
 import org.mule.RequestContext;
 import org.mule.api.MuleEvent;
-import org.mule.api.endpoint.ImmutableEndpoint;
 import org.mule.config.i18n.CoreMessages;
 import org.mule.config.i18n.Message;
 
+import java.net.URI;
+
 /**
  * <code>UnauthorisedException</code> is thrown if authentication fails
  */
@@ -49,17 +50,17 @@ public class UnauthorisedException extends SecurityException
 
     public UnauthorisedException(MuleEvent event, SecurityContext context, SecurityFilter filter)
     {
-        super(constructMessage(context, event.getEndpoint(), filter), event);
+        super(constructMessage(context, event.getMessageSourceURI(), filter), event);
     }
 
     @Deprecated
     public UnauthorisedException(MuleEvent event, SecurityContext context, 
-        ImmutableEndpoint endpoint, SecurityFilter filter)
+        URI endpointURI, SecurityFilter filter)
     {
-        super(constructMessage(context, endpoint, filter), event);
+        super(constructMessage(context, endpointURI, filter), event);
     }
 
-    private static Message constructMessage(SecurityContext context, ImmutableEndpoint endpoint,
+    private static Message constructMessage(SecurityContext context, URI endpointURI,
                                             SecurityFilter filter)
     {
 
@@ -72,7 +73,7 @@ public class UnauthorisedException extends SecurityException
         {
             m = CoreMessages.authFailedForUser(context.getAuthentication().getPrincipal());
         }
-        m.setNextMessage(CoreMessages.authDeniedOnEndpoint(endpoint.getEndpointURI()));
+        m.setNextMessage(CoreMessages.authDeniedOnEndpoint(endpointURI));
         return m;
     }
 }
