@@ -1,5 +1,5 @@
 /*
- * $Id: TlsConfiguration.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: TlsConfiguration.java 23743 2012-01-28 05:23:23Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -21,15 +21,19 @@ import org.mule.api.security.provider.SecurityProviderInfo;
 import org.mule.config.i18n.CoreMessages;
 import org.mule.util.FileUtils;
 import org.mule.util.IOUtils;
+import org.mule.util.StringUtils;
 
 import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.io.InputStream;
+import java.security.GeneralSecurityException;
 import java.security.KeyManagementException;
 import java.security.KeyStore;
+import java.security.KeyStoreException;
 import java.security.NoSuchAlgorithmException;
 import java.security.Provider;
 import java.security.Security;
+import java.util.Enumeration;
 
 import javax.net.ssl.KeyManager;
 import javax.net.ssl.KeyManagerFactory;
@@ -112,7 +116,6 @@ import org.apache.commons.logging.LogFactory;
 public final class TlsConfiguration
         implements TlsDirectTrustStore, TlsDirectKeyStore, TlsIndirectKeyStore, TlsProtocolHandler
 {
-
     public static final String DEFAULT_KEYSTORE = ".keystore";
     public static final String DEFAULT_KEYSTORE_TYPE = KeyStore.getDefaultType();
     public static final String JSSE_NAMESPACE = "javax.net";
@@ -130,6 +133,7 @@ public final class TlsConfiguration
     // this is the key store that is generated in-memory and available to connectors explicitly.
     // it is local to the socket.
     private String keyStoreName = DEFAULT_KEYSTORE; // was default in https but not ssl
+    private String keyAlias = null;
     private String keyPassword = null;
     private String keyStorePassword = null;
     private String keystoreType = DEFAULT_KEYSTORE_TYPE;
@@ -215,23 +219,19 @@ public final class TlsConfiguration
         {
             logger.debug("initialising key manager factory from keystore data");
         }
+
         KeyStore tempKeyStore;
         try
         {
-            tempKeyStore = KeyStore.getInstance(keystoreType);
-            InputStream is = IOUtils.getResourceAsStream(keyStoreName, getClass());
-            if (null == is)
-            {
-                throw new FileNotFoundException(
-                    CoreMessages.cannotLoadFromClasspath("Keystore: " + keyStoreName).getMessage());
-            }
-            tempKeyStore.load(is, keyStorePassword.toCharArray());
+            tempKeyStore = loadKeyStore();
+            checkKeyStoreContainsAlias(tempKeyStore);
         }
         catch (Exception e)
         {
             throw new CreateException(
                     CoreMessages.failedToLoad("KeyStore: " + keyStoreName), e, this);
         }
+
         try
         {
             keyManagerFactory = KeyManagerFactory.getInstance(getKeyManagerAlgorithm());
@@ -243,6 +243,54 @@ public final class TlsConfiguration
         }
     }
 
+    protected  KeyStore loadKeyStore() throws GeneralSecurityException, IOException
+    {
+        KeyStore tempKeyStore = KeyStore.getInstance(keystoreType);
+
+        InputStream is = IOUtils.getResourceAsStream(keyStoreName, getClass());
+        if (null == is)
+        {
+            throw new FileNotFoundException(
+                CoreMessages.cannotLoadFromClasspath("Keystore: " + keyStoreName).getMessage());
+        }
+
+        tempKeyStore.load(is, keyStorePassword.toCharArray());
+        return tempKeyStore;
+    }
+
+    protected void checkKeyStoreContainsAlias(KeyStore keyStore) throws KeyStoreException
+    {
+        if (StringUtils.isNotBlank(keyAlias))
+        {
+            boolean keyAliasFound = false;
+
+            Enumeration<String> aliases = keyStore.aliases();
+            while (aliases.hasMoreElements())
+            {
+                String alias = aliases.nextElement();
+
+                if (alias.equals(keyAlias))
+                {
+                    // if alias is found all is valid but continue processing to strip out all
+                    // other (unwanted) keys
+                    keyAliasFound = true;
+                }
+                else
+                {
+                    // if the current alias is not the one we are looking for, remove
+                    // it from the keystore
+                    keyStore.deleteEntry(alias);
+                }
+            }
+
+            // if the alias was not found, throw an exception
+            if (!keyAliasFound)
+            {
+                throw new IllegalStateException("Key with alias \"" + keyAlias + "\" was not found");
+            }
+        }
+    }
+
     private void initTrustManagerFactory() throws CreateException
     {
         if (null != trustStoreName)
@@ -345,11 +393,13 @@ public final class TlsConfiguration
         this.provider = provider;
     }
 
+    @Override
     public String getProtocolHandler()
     {
         return protocolHandler;
     }
 
+    @Override
     public void setProtocolHandler(String protocolHandler)
     {
         this.protocolHandler = protocolHandler;
@@ -367,11 +417,13 @@ public final class TlsConfiguration
 
     // access to the explicit key store variables
 
+    @Override
     public String getKeyStore()
     {
         return keyStoreName;
     }
 
+    @Override
     public void setKeyStore(String name) throws IOException
     {
         keyStoreName = name;
@@ -385,46 +437,55 @@ public final class TlsConfiguration
         }
     }
 
+    @Override
     public String getKeyPassword()
     {
         return keyPassword;
     }
 
+    @Override
     public void setKeyPassword(String keyPassword)
     {
         this.keyPassword = keyPassword;
     }
 
+    @Override
     public String getKeyStorePassword()
     {
         return keyStorePassword;
     }
 
+    @Override
     public void setKeyStorePassword(String storePassword)
     {
         this.keyStorePassword = storePassword;
     }
 
+    @Override
     public String getKeyStoreType()
     {
         return keystoreType;
     }
 
+    @Override
     public void setKeyStoreType(String keystoreType)
     {
         this.keystoreType = keystoreType;
     }
 
+    @Override
     public String getKeyManagerAlgorithm()
     {
         return keyManagerAlgorithm;
     }
 
+    @Override
     public void setKeyManagerAlgorithm(String keyManagerAlgorithm)
     {
         this.keyManagerAlgorithm = keyManagerAlgorithm;
     }
 
+    @Override
     public KeyManagerFactory getKeyManagerFactory()
     {
         return keyManagerFactory;
@@ -432,11 +493,13 @@ public final class TlsConfiguration
 
     // access to the implicit key store variables
 
+    @Override
     public String getClientKeyStore()
     {
         return clientKeyStoreName;
     }
 
+    @Override
     public void setClientKeyStore(String name) throws IOException
     {
         clientKeyStoreName = name;
@@ -450,21 +513,25 @@ public final class TlsConfiguration
         }
     }
 
+    @Override
     public String getClientKeyStorePassword()
     {
         return clientKeyStorePassword;
     }
 
+    @Override
     public void setClientKeyStorePassword(String clientKeyStorePassword)
     {
         this.clientKeyStorePassword = clientKeyStorePassword;
     }
 
+    @Override
     public void setClientKeyStoreType(String clientKeyStoreType)
     {
         this.clientKeyStoreType = clientKeyStoreType;
     }
 
+    @Override
     public String getClientKeyStoreType()
     {
         return clientKeyStoreType;
@@ -472,11 +539,13 @@ public final class TlsConfiguration
 
     // access to trust store variables
 
+    @Override
     public String getTrustStore()
     {
         return trustStoreName;
     }
 
+    @Override
     public void setTrustStore(String name) throws IOException
     {
         trustStoreName = name;
@@ -490,66 +559,89 @@ public final class TlsConfiguration
         }
     }
 
+    @Override
     public String getTrustStorePassword()
     {
         return trustStorePassword;
     }
 
+    @Override
     public void setTrustStorePassword(String trustStorePassword)
     {
         this.trustStorePassword = trustStorePassword;
     }
 
+    @Override
     public String getTrustStoreType()
     {
         return trustStoreType;
     }
 
+    @Override
     public void setTrustStoreType(String trustStoreType)
     {
         this.trustStoreType = trustStoreType;
     }
 
+    @Override
     public String getTrustManagerAlgorithm()
     {
         return trustManagerAlgorithm;
     }
 
+    @Override
     public void setTrustManagerAlgorithm(String trustManagerAlgorithm)
     {
         this.trustManagerAlgorithm = defaultForNull(trustManagerAlgorithm, spInfo.getKeyManagerAlgorithm());
     }
 
+    @Override
     public TrustManagerFactory getTrustManagerFactory()
     {
         return trustManagerFactory;
     }
 
+    @Override
     public void setTrustManagerFactory(TrustManagerFactory trustManagerFactory)
     {
         this.trustManagerFactory = trustManagerFactory;
     }
 
+    @Override
     public boolean isExplicitTrustStoreOnly()
     {
         return explicitTrustStoreOnly;
     }
 
+    @Override
     public void setExplicitTrustStoreOnly(boolean explicitTrustStoreOnly)
     {
         this.explicitTrustStoreOnly = explicitTrustStoreOnly;
     }
 
+    @Override
     public boolean isRequireClientAuthentication()
     {
         return requireClientAuthentication;
     }
 
+    @Override
     public void setRequireClientAuthentication(boolean requireClientAuthentication)
     {
         this.requireClientAuthentication = requireClientAuthentication;
     }
 
+    @Override
+    public String getKeyAlias()
+    {
+        return keyAlias;
+    }
+
+    @Override
+    public void setKeyAlias(String keyAlias)
+    {
+        this.keyAlias = keyAlias;
+    }
 }
 
 
