@@ -1,5 +1,5 @@
 /*
- * $Id: ReplyToHandler.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: ReplyToHandler.java 22497 2011-07-21 12:12:26Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,9 +13,6 @@ package org.mule.api.transport;
 import org.mule.api.MuleEvent;
 import org.mule.api.MuleException;
 import org.mule.api.MuleMessage;
-import org.mule.api.transformer.Transformer;
-
-import java.util.List;
 
 /**
  * <code>ReplyToHandler</code> is used to handle routing where a replyTo endpointUri is
@@ -26,7 +23,4 @@ public interface ReplyToHandler
 {
     void processReplyTo(MuleEvent event, MuleMessage returnMessage, Object replyTo) throws MuleException;
 
-    void setTransformers(List<Transformer> transformers);
-
-    List<Transformer> getTransformers();
 }
