@@ -1,5 +1,5 @@
 /*
- * $Id: DefaultJavaComponentTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: DefaultJavaComponentTestCase.java 22377 2011-07-11 12:41:42Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -18,6 +18,14 @@ import org.mule.model.seda.SedaService;
 import org.mule.object.PrototypeObjectFactory;
 import org.mule.tck.testmodels.fruit.Orange;
 
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNotSame;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+
 public class DefaultJavaComponentTestCase extends AbstractComponentTestCase
 {
 
@@ -28,6 +36,7 @@ public class DefaultJavaComponentTestCase extends AbstractComponentTestCase
         return objectFactory;
     }
 
+    @Test
     public void testComponentCreation() throws Exception
     {
         ObjectFactory objectFactory = createObjectFactory();
@@ -39,6 +48,7 @@ public class DefaultJavaComponentTestCase extends AbstractComponentTestCase
         assertEquals(Orange.class, component.getObjectType());
     }
 
+    @Test
     public void testLifecycle() throws Exception
     {
         DefaultJavaComponent component = new DefaultJavaComponent(createObjectFactory());
@@ -62,6 +72,7 @@ public class DefaultJavaComponentTestCase extends AbstractComponentTestCase
 
     }
 
+    @Test
     public void testComponentDisposal() throws Exception
     {
         DefaultJavaComponent component = new DefaultJavaComponent(
@@ -75,12 +86,14 @@ public class DefaultJavaComponentTestCase extends AbstractComponentTestCase
         DefaultComponentLifecycleAdapter lifecycleAdapter = (DefaultComponentLifecycleAdapter) 
             component.borrowComponentLifecycleAdaptor();
         component.returnComponentLifecycleAdaptor(lifecycleAdapter);
+        component.stop();
         component.dispose();
 
         assertNull(lifecycleAdapter.componentObject);
     }
     
-    public void testServicePropogatedLifecycle() throws InitialisationException
+    @Test
+    public void testServicePropagatedLifecycle() throws InitialisationException
     {
         Service service = new SedaService(muleContext);
         service.setName("service");
