@@ -1,5 +1,5 @@
 /*
- * $Id: DefaultMuleConfiguration.java 21328 2011-02-21 08:13:35Z dirk.olmes $
+ * $Id: DefaultMuleConfiguration.java 24450 2012-05-29 19:39:09Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -44,6 +44,8 @@ import org.apache.commons.logging.LogFactory;
 public class DefaultMuleConfiguration implements MuleConfiguration, MuleContextAware
 {
 
+    public static final boolean DEFAULT_TRANSFORMATION_RESOLVE_NON_DIRECT = true;
+
     public static final String[] DEFAULT_STACKTRACE_FILTER = (
             "org.mule.processor.AbstractInterceptingMessageProcessor," +
             "org.mule.processor.chain")
@@ -90,7 +92,7 @@ public class DefaultMuleConfiguration implements MuleConfiguration, MuleContextA
      * has been set on the transaction config
      */
     private int defaultTransactionTimeout = 30000;
-    
+
     /**
      * The default queue timeout value used when polling queues.
      */
@@ -120,13 +122,13 @@ public class DefaultMuleConfiguration implements MuleConfiguration, MuleContextA
     private String id;
 
     /** If this node is part of a cluster then this is the shared cluster Id */
-    private String clusterId;
+    private String clusterId = "";
 
     /** The domain name that this instance belongs to. */
     private String domainId;
 
     // Debug options
-    
+
     private boolean cacheMessageAsBytes = true;
 
     private boolean cacheMessageOriginalPayload = true;
@@ -134,7 +136,7 @@ public class DefaultMuleConfiguration implements MuleConfiguration, MuleContextA
     private boolean enableStreaming = true;
 
     private boolean autoWrapMessageAwareTransform = true;
-    
+
     protected transient Log logger = LogFactory.getLog(DefaultMuleConfiguration.class);
 
     private MuleContext muleContext;
@@ -148,34 +150,40 @@ public class DefaultMuleConfiguration implements MuleConfiguration, MuleContextA
      */
     private boolean validateExpressions = true;
 
+    private boolean useExtendedTransformations = DEFAULT_TRANSFORMATION_RESOLVE_NON_DIRECT;
+
+    private boolean flowEndingWithOneWayEndpointReturnsNull;
+    
+    private boolean enricherPropagatesSessionVariableChanges;
+
     /**
      * Generic string/string map of properties in addition to standard Mule props.
      * Used as an extension point e.g. in MMC.
      */
     private Map<String, String> extendedProperties = new HashMap<String, String>();
 
+    /**
+     * Global exception strategy name to be used as default exception strategy for flows and services
+     */
+    private String defaultExceptionStrategyName;
+
     public DefaultMuleConfiguration()
     {
         this(false);
     }
 
-    public DefaultMuleConfiguration(boolean containerMode)  
+    public DefaultMuleConfiguration(boolean containerMode)
     {
         this.containerMode = containerMode;
-        
+
         // Apply any settings which come from the JVM system properties.
         applySystemProperties();
-        
+
         if (id == null)
         {
             id = UUID.getUUID();
         }
 
-        if (clusterId == null)
-        {
-            clusterId = CoreMessages.notClustered().getMessage();
-        }
-
         if (domainId == null)
         {
             try
@@ -188,7 +196,7 @@ public class DefaultMuleConfiguration implements MuleConfiguration, MuleContextA
                 domainId = "org.mule";
             }
         }
-        
+
         try
         {
             validateEncoding();
@@ -225,10 +233,10 @@ public class DefaultMuleConfiguration implements MuleConfiguration, MuleContextA
     /**
      * Apply any settings which come from the JVM system properties.
      */
-    protected void applySystemProperties() 
+    protected void applySystemProperties()
     {
         String p;
-        
+
         p = System.getProperty(MuleProperties.MULE_ENCODING_SYSTEM_PROPERTY);
         if (p != null)
         {
@@ -274,11 +282,6 @@ public class DefaultMuleConfiguration implements MuleConfiguration, MuleContextA
         {
             id = p;
         }
-        p = System.getProperty(MuleProperties.SYSTEM_PROPERTY_PREFIX + "clusterId");
-        if (p != null)
-        {
-            clusterId = p;
-        }
         p = System.getProperty(MuleProperties.SYSTEM_PROPERTY_PREFIX + "domainId");
         if (p != null)
         {
@@ -422,7 +425,6 @@ public class DefaultMuleConfiguration implements MuleConfiguration, MuleContextA
         }
     }
 
-
     public boolean isValidateExpressions()
     {
         return validateExpressions;
@@ -463,17 +465,9 @@ public class DefaultMuleConfiguration implements MuleConfiguration, MuleContextA
         }
     }
 
-    public String getClusterId()
-    {
-        return clusterId;
-    }
-
     public void setClusterId(String clusterId)
     {
-        if (verifyContextNotInitialized())
-        {
-            this.clusterId = clusterId;
-        }
+        this.clusterId = clusterId;
     }
 
     public String getDomainId()
@@ -514,7 +508,7 @@ public class DefaultMuleConfiguration implements MuleConfiguration, MuleContextA
     {
         return domainId + "." + clusterId + "." + id;
     }
-    
+
     public boolean isAutoWrapMessageAwareTransform()
     {
         return autoWrapMessageAwareTransform;
@@ -579,7 +573,7 @@ public class DefaultMuleConfiguration implements MuleConfiguration, MuleContextA
             return true;
         }
     }
-    
+
     protected boolean verifyContextNotStarted()
     {
         if (muleContext != null && muleContext.getLifecycleManager().isPhaseComplete(Startable.PHASE_NAME))
@@ -661,6 +655,51 @@ public class DefaultMuleConfiguration implements MuleConfiguration, MuleContextA
         return this.extendedProperties.get(name);
     }
 
+    public String getDefaultExceptionStrategyName()
+    {
+        return defaultExceptionStrategyName;
+    }
+
+    public void setUseExtendedTransformations(boolean useExtendedTransformations)
+    {
+        if (verifyContextNotStarted())
+        {
+            this.useExtendedTransformations = useExtendedTransformations;
+        }
+    }
+
+    @Override
+    public boolean useExtendedTransformations()
+    {
+        return useExtendedTransformations;
+    }
+
+    public void setFlowEndingWithOneWayEndpointReturnsNull(boolean flowEndingWithOneWayEndpointReturnsNull)
+    {
+        this.flowEndingWithOneWayEndpointReturnsNull = flowEndingWithOneWayEndpointReturnsNull;
+    }
+
+    @Override
+    public boolean isFlowEndingWithOneWayEndpointReturnsNull()
+    {
+        return flowEndingWithOneWayEndpointReturnsNull;
+    }
+
+    public void setDefaultExceptionStrategyName(String defaultExceptionStrategyName)
+    {
+        this.defaultExceptionStrategyName = defaultExceptionStrategyName;
+    }
+    
+    public boolean isEnricherPropagatesSessionVariableChanges()
+    {
+        return enricherPropagatesSessionVariableChanges;
+    }
+
+    public void setEnricherPropagatesSessionVariableChanges(boolean enricherPropagatesSessionVariableChanges)
+    {
+        this.enricherPropagatesSessionVariableChanges = enricherPropagatesSessionVariableChanges;
+    }
+
     @Override
     public int hashCode()
     {
@@ -670,7 +709,6 @@ public class DefaultMuleConfiguration implements MuleConfiguration, MuleContextA
         result = prime * result + (cacheMessageAsBytes ? 1231 : 1237);
         result = prime * result + (cacheMessageOriginalPayload ? 1231 : 1237);
         result = prime * result + (clientMode ? 1231 : 1237);
-        result = prime * result + ((clusterId == null) ? 0 : clusterId.hashCode());
         result = prime * result + defaultQueueTimeout;
         result = prime * result + defaultTransactionTimeout;
         result = prime * result + ((domainId == null) ? 0 : domainId.hashCode());
@@ -679,6 +717,8 @@ public class DefaultMuleConfiguration implements MuleConfiguration, MuleContextA
         result = prime * result + ((id == null) ? 0 : id.hashCode());
         result = prime * result + responseTimeout;
         result = prime * result + shutdownTimeout;
+        result = prime * result + (useExtendedTransformations ? 1231 : 1237);
+        result = prime * result + (flowEndingWithOneWayEndpointReturnsNull ? 1231 : 1237);
         result = prime * result + (synchronous ? 1231 : 1237);
         result = prime * result + ((systemModelType == null) ? 0 : systemModelType.hashCode());
         result = prime * result + ((workingDirectory == null) ? 0 : workingDirectory.hashCode());
@@ -689,52 +729,127 @@ public class DefaultMuleConfiguration implements MuleConfiguration, MuleContextA
     @Override
     public boolean equals(Object obj)
     {
-        if (this == obj) return true;
-        if (obj == null) return false;
-        if (getClass() != obj.getClass()) return false;
-        DefaultMuleConfiguration other = (DefaultMuleConfiguration) obj;
-        if (autoWrapMessageAwareTransform != other.autoWrapMessageAwareTransform) return false;
-        if (cacheMessageAsBytes != other.cacheMessageAsBytes) return false;
-        if (cacheMessageOriginalPayload != other.cacheMessageOriginalPayload) return false;
-        if (clientMode != other.clientMode) return false;
-        if (clusterId == null)
+        if (this == obj)
         {
-            if (other.clusterId != null) return false;
+            return true;
+        }
+        if (obj == null)
+        {
+            return false;
+        }
+        if (getClass() != obj.getClass())
+        {
+            return false;
+        }
+        DefaultMuleConfiguration other = (DefaultMuleConfiguration) obj;
+        if (autoWrapMessageAwareTransform != other.autoWrapMessageAwareTransform)
+        {
+            return false;
+        }
+        if (cacheMessageAsBytes != other.cacheMessageAsBytes)
+        {
+            return false;
+        }
+        if (cacheMessageOriginalPayload != other.cacheMessageOriginalPayload)
+        {
+            return false;
+        }
+        if (clientMode != other.clientMode)
+        {
+            return false;
+        }
+        if (defaultQueueTimeout != other.defaultQueueTimeout)
+        {
+            return false;
+        }
+        if (defaultTransactionTimeout != other.defaultTransactionTimeout)
+        {
+            return false;
         }
-        else if (!clusterId.equals(other.clusterId)) return false;
-        if (defaultQueueTimeout != other.defaultQueueTimeout) return false;
-        if (defaultTransactionTimeout != other.defaultTransactionTimeout) return false;
         if (domainId == null)
         {
-            if (other.domainId != null) return false;
+            if (other.domainId != null)
+            {
+                return false;
+            }
+        }
+        else if (!domainId.equals(other.domainId))
+        {
+            return false;
+        }
+        if (enableStreaming != other.enableStreaming)
+        {
+            return false;
         }
-        else if (!domainId.equals(other.domainId)) return false;
-        if (enableStreaming != other.enableStreaming) return false;
         if (encoding == null)
         {
-            if (other.encoding != null) return false;
+            if (other.encoding != null)
+            {
+                return false;
+            }
+        }
+        else if (!encoding.equals(other.encoding))
+        {
+            return false;
         }
-        else if (!encoding.equals(other.encoding)) return false;
         if (id == null)
         {
-            if (other.id != null) return false;
+            if (other.id != null)
+            {
+                return false;
+            }
+        }
+        else if (!id.equals(other.id))
+        {
+            return false;
+        }
+        if (responseTimeout != other.responseTimeout)
+        {
+            return false;
+        }
+        if (shutdownTimeout != other.shutdownTimeout)
+        {
+            return false;
+        }
+        if (useExtendedTransformations != other.useExtendedTransformations)
+        {
+            return false;
+        }
+        if (flowEndingWithOneWayEndpointReturnsNull != other.flowEndingWithOneWayEndpointReturnsNull)
+        {
+            return false;
+        }
+        if (synchronous != other.synchronous)
+        {
+            return false;
         }
-        else if (!id.equals(other.id)) return false;
-        if (responseTimeout != other.responseTimeout) return false;
-        if (shutdownTimeout != other.shutdownTimeout) return false;
-        if (synchronous != other.synchronous) return false;
         if (systemModelType == null)
         {
-            if (other.systemModelType != null) return false;
+            if (other.systemModelType != null)
+            {
+                return false;
+            }
+        }
+        else if (!systemModelType.equals(other.systemModelType))
+        {
+            return false;
         }
-        else if (!systemModelType.equals(other.systemModelType)) return false;
         if (workingDirectory == null)
         {
-            if (other.workingDirectory != null) return false;
+            if (other.workingDirectory != null)
+            {
+                return false;
+            }
+        }
+        else if (!workingDirectory.equals(other.workingDirectory))
+        {
+            return false;
         }
-        else if (!workingDirectory.equals(other.workingDirectory)) return false;
 
-        if (containerMode != other.containerMode) return false;
+        if (containerMode != other.containerMode)
+        {
+            return false;
+        }
 
         return true;
     }
