@@ -1,5 +1,5 @@
 /*
- * $Id: ContentBasedRouter.java 20875 2011-01-04 16:09:25Z aperepel $
+ * $Id: ContentBasedRouter.java 24217 2012-04-03 14:29:27Z pablo.lagreca $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -38,9 +38,13 @@ public class ContentBasedRouter extends AbstractOutboundRouter
                     return target.process(event);
                 }
             }
+            catch (MessagingException e)
+            {
+                throw e;
+            }
             catch (MuleException e)
             {
-                throw new MessagingException(e.getI18nMessage(), theEvent, e);
+                throw new MessagingException(e.getI18nMessage(), theEvent, e, this);
             }
         }
         //TODO
