@@ -1,5 +1,5 @@
 /*
- * $Id: ThreadPoolFactory.java 20909 2011-01-05 20:48:58Z pablo.kraan $
+ * $Id: ThreadPoolFactory.java 21939 2011-05-18 13:32:09Z aperepel $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -18,11 +18,10 @@ import org.mule.config.PreferredObjectSelector;
 import org.mule.config.i18n.MessageFactory;
 
 import java.util.Iterator;
+import java.util.concurrent.ThreadPoolExecutor;
 
 import javax.imageio.spi.ServiceRegistry;
 
-import edu.emory.mathcs.backport.java.util.concurrent.ThreadPoolExecutor;
-
 /**
  * Uses a standard JDK's
  * <a href="http://java.sun.com/j2se/1.3/docs/guide/jar/jar.html#Service%20Provider">SPI discovery</a>
