@@ -1,5 +1,5 @@
 /*
- * $Id: DeclarativeCustomExpressionEvaluatorTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: DeclarativeCustomExpressionEvaluatorTestCase.java 22414 2011-07-14 13:24:46Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -11,16 +11,22 @@
 package org.mule.config.spring;
 
 import org.mule.expression.CustomExpressionEvaluatorTestCase;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.junit4.FunctionalTestCase;
+
+import org.junit.Test;
+
+import static org.junit.Assert.assertTrue;
 
 public class DeclarativeCustomExpressionEvaluatorTestCase extends FunctionalTestCase
 {
 
+    @Override
     protected String getConfigResources()
     {
         return "org/mule/config/spring/declarative-custom-expression-evaluator-test.xml";
     }
 
+    @Test
     public void testCustomEvalutorRegistered()
     {
         CustomExpressionEvaluatorTestCase.FooExpressionEvaluator customEvaluator =
