@@ -1,5 +1,5 @@
 /*
- * $Id: SimpleServiceFactoryBean.java 20320 2010-11-24 15:03:31Z dfeist $
+ * $Id: SimpleServiceFactoryBean.java 21683 2011-04-14 22:07:56Z ddossot $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -65,12 +65,12 @@ public class SimpleServiceFactoryBean extends AbstractFlowConstructFactoryBean
 
     public void setTransformers(Transformer... transformers)
     {
-        simpleServiceBuilder.inboundTransformers(transformers);
+        simpleServiceBuilder.transformers(transformers);
     }
 
     public void setResponseTransformers(Transformer... responseTransformers)
     {
-        simpleServiceBuilder.inboundResponseTransformers(responseTransformers);
+        simpleServiceBuilder.responseTransformers(responseTransformers);
     }
 
     public void setComponentClass(Class<?> componentClass)
