@@ -12,11 +12,13 @@ package org.mule.config.spring.parsers;
 import org.mule.api.MuleContext;
 import org.mule.api.component.Component;
 import org.mule.api.config.MuleProperties;
+import org.mule.api.exception.MessagingExceptionHandler;
 import org.mule.api.lifecycle.Disposable;
 import org.mule.api.lifecycle.Initialisable;
 import org.mule.api.routing.OutboundRouter;
 import org.mule.api.routing.OutboundRouterCollection;
 import org.mule.api.source.MessageSource;
+import org.mule.api.transformer.Transformer;
 import org.mule.config.spring.MuleHierarchicalBeanDefinitionParserDelegate;
 import org.mule.config.spring.parsers.assembly.BeanAssembler;
 import org.mule.config.spring.parsers.assembly.BeanAssemblerFactory;
@@ -24,13 +26,13 @@ import org.mule.config.spring.parsers.assembly.DefaultBeanAssemblerFactory;
 import org.mule.config.spring.parsers.assembly.configuration.ReusablePropertyConfiguration;
 import org.mule.config.spring.parsers.assembly.configuration.ValueMap;
 import org.mule.config.spring.parsers.generic.AutoIdUtils;
+import org.mule.enricher.MessageEnricher;
 import org.mule.exception.AbstractExceptionListener;
 import org.mule.util.ClassUtils;
 import org.mule.util.StringUtils;
 import org.mule.util.XMLUtils;
 
 import java.util.HashSet;
-import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
@@ -95,7 +97,6 @@ import org.w3c.dom.NamedNodeMap;
 public abstract class AbstractMuleBeanDefinitionParser extends AbstractBeanDefinitionParser
     implements MuleDefinitionParser
 {
-
     public static final String ROOT_ELEMENT = "mule";
     public static final String ATTRIBUTE_ID = "id";
     public static final String ATTRIBUTE_NAME = "name";
@@ -114,16 +115,16 @@ public abstract class AbstractMuleBeanDefinitionParser extends AbstractBeanDefin
     protected ReusablePropertyConfiguration beanPropertyConfiguration = new ReusablePropertyConfiguration();
     private ParserContext parserContext;
     private BeanDefinitionRegistry registry;
-    private LinkedList preProcessors = new LinkedList();
-    private List postProcessors = new LinkedList();
-    private Set beanAttributes = new HashSet();
+    private LinkedList<PreProcessor> preProcessors = new LinkedList<PreProcessor>();
+    private List<PostProcessor> postProcessors = new LinkedList<PostProcessor>();
+    private Set<String> beanAttributes = new HashSet<String>();
     // By default Mule objects are not singletons
     protected boolean singleton = false;
 
     /** Allow the bean class to be set explicitly via the "class" attribute. */
     private boolean allowClassAttribute = true;
-    private Class classConstraint = null;
-    
+    private Class<?> classConstraint = null;
+
     private String deprecationWarning;
 
     public AbstractMuleBeanDefinitionParser()
@@ -214,13 +215,13 @@ public abstract class AbstractMuleBeanDefinitionParser extends AbstractBeanDefin
     protected void postProcess(ParserContext context, BeanAssembler assembler, Element element)
     {
         element.setAttribute(ATTRIBUTE_NAME, getBeanName(element));
-        for (Iterator attributes = beanAttributes.iterator(); attributes.hasNext();)
+        for (String attribute : beanAttributes)
         {
-            assembler.setBeanFlag((String) attributes.next());
+            assembler.setBeanFlag(attribute);
         }
-        for (Iterator processes = postProcessors.iterator(); processes.hasNext();)
+        for (PostProcessor processor : postProcessors)
         {
-            ((PostProcessor) processes.next()).postProcess(context, assembler, element);
+            processor.postProcess(context, assembler, element);
         }
     }
 
@@ -236,35 +237,35 @@ public abstract class AbstractMuleBeanDefinitionParser extends AbstractBeanDefin
         parserContext = null;
         registry = null;
         beanPropertyConfiguration.reset();
-        Iterator processes = preProcessors.iterator();
-        while (processes.hasNext())
+        for (PreProcessor processor : preProcessors)
         {
-            ((PreProcessor) processes.next()).preProcess(beanPropertyConfiguration, element);
+            processor.preProcess(beanPropertyConfiguration, element);
         }
     }
 
     /**
-     * Creates a {@link BeanDefinitionBuilder} instance for the
-     * {@link #getBeanClass bean Class} and passes it to the
-     * {@link #doParse} strategy method.
+     * Creates a {@link BeanDefinitionBuilder} instance for the {@link #getBeanClass
+     * bean Class} and passes it to the {@link #doParse} strategy method.
      *
-     * @param element       the element that is to be parsed into a single BeanDefinition
-     * @param parserContext the object encapsulating the current state of the parsing process
-     * @return the BeanDefinition resulting from the parsing of the supplied {@link Element}
+     * @param element the element that is to be parsed into a single BeanDefinition
+     * @param context the object encapsulating the current state of the parsing
+     *            process
+     * @return the BeanDefinition resulting from the parsing of the supplied
+     *         {@link Element}
      * @throws IllegalStateException if the bean {@link Class} returned from
-     *                               {@link #getBeanClass(org.w3c.dom.Element)} is <code>null</code>
+     *             {@link #getBeanClass(org.w3c.dom.Element)} is <code>null</code>
      * @see #doParse
      */
     @Override
-    protected AbstractBeanDefinition parseInternal(Element element, ParserContext parserContext)
+    protected AbstractBeanDefinition parseInternal(Element element, ParserContext context)
     {
         preProcess(element);
-        setParserContext(parserContext);
-        setRegistry(parserContext.getRegistry());
+        setParserContext(context);
+        setRegistry(context.getRegistry());
         checkElementNameUnique(element);
-        Class beanClass = getClassInternal(element);
+        Class<?> beanClass = getClassInternal(element);
         BeanDefinitionBuilder builder = createBeanDefinitionBuilder(element, beanClass);
-        builder.getRawBeanDefinition().setSource(parserContext.extractSource(element));
+        builder.getRawBeanDefinition().setSource(context.extractSource(element));
         builder.setScope(isSingleton() ? BeanDefinition.SCOPE_SINGLETON : BeanDefinition.SCOPE_PROTOTYPE);
 
         // Marker for MULE-4813
@@ -272,7 +273,10 @@ public abstract class AbstractMuleBeanDefinitionParser extends AbstractBeanDefin
         if (!Component.class.isAssignableFrom(beanClass) && !MessageSource.class.isAssignableFrom(beanClass)
             && !OutboundRouterCollection.class.isAssignableFrom(beanClass)
             && !OutboundRouter.class.isAssignableFrom(beanClass)
-            && !AbstractExceptionListener.class.isAssignableFrom(beanClass))
+            && !AbstractExceptionListener.class.isAssignableFrom(beanClass)
+            && !MessagingExceptionHandler.class.isAssignableFrom(beanClass)
+            && !MessageEnricher.class.isAssignableFrom(beanClass)
+            && !Transformer.class.isAssignableFrom(beanClass))
         {
             if (Initialisable.class.isAssignableFrom(beanClass))
             {
@@ -285,14 +289,14 @@ public abstract class AbstractMuleBeanDefinitionParser extends AbstractBeanDefin
             }
         }
 
-        if (parserContext.isNested())
+        if (context.isNested())
         {
             // Inner bean definition must receive same singleton status as containing bean.
-            builder.setScope(parserContext.getContainingBeanDefinition().isSingleton() 
+            builder.setScope(context.getContainingBeanDefinition().isSingleton()
                 ? BeanDefinition.SCOPE_SINGLETON : BeanDefinition.SCOPE_PROTOTYPE);
         }
 
-        doParse(element, parserContext, builder);
+        doParse(element, context, builder);
         return builder.getBeanDefinition();
     }
 
@@ -322,7 +326,7 @@ public abstract class AbstractMuleBeanDefinitionParser extends AbstractBeanDefin
         }
     }
 
-    protected BeanDefinitionBuilder createBeanDefinitionBuilder(Element element, Class beanClass)
+    protected BeanDefinitionBuilder createBeanDefinitionBuilder(Element element, Class<?> beanClass)
     {
         BeanDefinitionBuilder builder = BeanDefinitionBuilder.rootBeanDefinition(beanClass);
         // If a constructor with a single MuleContext argument is available then use it.
@@ -333,9 +337,9 @@ public abstract class AbstractMuleBeanDefinitionParser extends AbstractBeanDefin
         return builder;
     }
 
-    protected Class getClassInternal(Element element)
+    protected Class<?> getClassInternal(Element element)
     {
-        Class beanClass = null;
+        Class<?> beanClass = null;
         if (isAllowClassAttribute())
         {
             beanClass = getBeanClassFromAttribute(element);
@@ -398,20 +402,22 @@ public abstract class AbstractMuleBeanDefinitionParser extends AbstractBeanDefin
     /**
      * Parse the supplied {@link Element} and populate the supplied
      * {@link BeanDefinitionBuilder} as required.
-     * <p>The default implementation delegates to the <code>doParse</code>
-     * version without ParserContext argument.
+     * <p>
+     * The default implementation delegates to the <code>doParse</code> version
+     * without ParserContext argument.
      *
-     * @param element       the XML element being parsed
-     * @param parserContext the object encapsulating the current state of the parsing process
-     * @param builder       used to define the <code>BeanDefinition</code>
+     * @param element the XML element being parsed
+     * @param context the object encapsulating the current state of the parsing
+     *            process
+     * @param builder used to define the <code>BeanDefinition</code>
      */
-    protected void doParse(Element element, ParserContext parserContext, BeanDefinitionBuilder builder)
+    protected void doParse(Element element, ParserContext context, BeanDefinitionBuilder builder)
     {
         if (deprecationWarning != null && logger.isWarnEnabled())
         {
             logger.warn("Schema warning: Use of element <" + element.getLocalName() + "> is deprecated.  " + deprecationWarning);
         }
-        
+
         BeanAssembler assembler = getBeanAssembler(element, builder);
         NamedNodeMap attributes = element.getAttributes();
         for (int x = 0; x < attributes.getLength(); x++)
@@ -423,7 +429,8 @@ public abstract class AbstractMuleBeanDefinitionParser extends AbstractBeanDefin
     }
 
     @Override
-    protected String resolveId(Element element, AbstractBeanDefinition definition, ParserContext parserContext) throws BeanDefinitionStoreException
+    protected String resolveId(Element element, AbstractBeanDefinition definition,
+        ParserContext context) throws BeanDefinitionStoreException
     {
         return getBeanName(element);
     }
@@ -456,12 +463,12 @@ public abstract class AbstractMuleBeanDefinitionParser extends AbstractBeanDefin
         this.allowClassAttribute = allowClassAttribute;
     }
 
-    protected Class getClassConstraint()
+    protected Class<?> getClassConstraint()
     {
         return classConstraint;
     }
 
-    protected void setClassConstraint(Class classConstraint)
+    protected void setClassConstraint(Class<?> classConstraint)
     {
         this.classConstraint = classConstraint;
     }
@@ -485,9 +492,9 @@ public abstract class AbstractMuleBeanDefinitionParser extends AbstractBeanDefin
         return element.getParentNode().getLocalName().equals(ROOT_ELEMENT);
     }
 
-    public AbstractBeanDefinition muleParse(Element element, ParserContext parserContext)
+    public AbstractBeanDefinition muleParse(Element element, ParserContext context)
     {
-        return parseInternal(element, parserContext);
+        return parseInternal(element, context);
     }
 
     public MuleDefinitionParserConfiguration registerPreProcessor(PreProcessor preProcessor)
