@@ -1,5 +1,5 @@
 /*
- * $Id: OrphanSimpleTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: OrphanSimpleTestCase.java 22414 2011-07-14 13:24:46Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,14 +13,18 @@ package org.mule.config.spring.parsers;
 import org.mule.config.spring.parsers.beans.ChildBean;
 import org.mule.config.spring.parsers.beans.OrphanBean;
 
+import org.junit.Test;
+
 public class OrphanSimpleTestCase extends AbstractNamespaceTestCase
 {
 
+    @Override
     protected String getConfigResources()
     {
         return "org/mule/config/spring/parsers/orphan-simple-test.xml";
     }
 
+    @Test
     public void testOrphan2()
     {
         OrphanBean orphan2 = (OrphanBean) assertBeanExists("orphan2", OrphanBean.class);
