@@ -1,5 +1,5 @@
 /*
- * $Id: ParentNamespaceTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: ParentNamespaceTestCase.java 22414 2011-07-14 13:24:46Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,14 +13,18 @@ package org.mule.config.spring.parsers;
 import org.mule.config.spring.parsers.beans.ChildBean;
 import org.mule.config.spring.parsers.beans.OrphanBean;
 
+import org.junit.Test;
+
 public class ParentNamespaceTestCase extends AbstractNamespaceTestCase
 {
 
+    @Override
     protected String getConfigResources()
     {
         return "org/mule/config/spring/parsers/parsers-test-namespace-config.xml";
     }
 
+    @Test
     public void testParent()
     {
         OrphanBean orphan3 = (OrphanBean) assertBeanExists("orphan3", OrphanBean.class);
