@@ -1,5 +1,5 @@
 /*
- * $Id: DefaultNameMuleOrphanDefinitionParser.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id: DefaultNameMuleOrphanDefinitionParser.java 21762 2011-05-03 01:29:28Z mike.schilling $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -17,9 +17,18 @@ public class DefaultNameMuleOrphanDefinitionParser extends MuleOrphanDefinitionP
 {
 
     public DefaultNameMuleOrphanDefinitionParser()
+    {
+        this(false);
+    }
+
+    public DefaultNameMuleOrphanDefinitionParser(boolean ignoreName)
     {
         super(true);
         registerPreProcessor(new ProvideDefaultNameFromElement());
+        if (ignoreName)
+        {
+            addIgnored(ATTRIBUTE_NAME);
+        }
     }
 
     public DefaultNameMuleOrphanDefinitionParser(Class beanClass)
