@@ -1,5 +1,5 @@
 /*
- * $Id: MethodInvokerDefinitionParserTestCase.java 20367 2010-11-27 12:40:06Z dfeist $
+ * $Id: MethodInvokerDefinitionParserTestCase.java 22414 2011-07-14 13:24:46Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,23 +10,27 @@
 
 package org.mule.config.spring.parsers.specific;
 
-import org.mule.construct.SimpleFlowConstruct;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.construct.Flow;
+import org.mule.tck.junit4.FunctionalTestCase;
+
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
 
 public class MethodInvokerDefinitionParserTestCase extends FunctionalTestCase
 {
 
+    @Test
     public void testPojoFlow() throws Exception
     {
-        SimpleFlowConstruct flow = muleContext.getRegistry().lookupObject("pojoFlow");
-        SimpleFlowConstruct flow2 = muleContext.getRegistry().lookupObject("pojoFlow2");
+        Flow flow = muleContext.getRegistry().lookupObject("pojoFlow");
+        Flow flow2 = muleContext.getRegistry().lookupObject("pojoFlow2");
 
         assertEquals("start nullmethod2Arg1Arg2config2Val arg2Valmethod2Arg1Arg2config2Val ", flow.process(
             getTestEvent("start ")).getMessageAsString());
 
         assertEquals("start nullmethod2Arg1Arg2null arg2Valmethod2Arg1Arg2null ", flow2.process(
             getTestEvent("start ")).getMessageAsString());
-
     }
 
     @Override
