@@ -1,5 +1,5 @@
 /*
- * $Id: MessageProcessorNotification.java 21284 2011-02-15 18:47:04Z dfeist $
+ * $Id: MessageProcessorNotification.java 24265 2012-04-16 06:54:00Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,17 +10,20 @@
 
 package org.mule.context.notification;
 
+import org.mule.DefaultMuleEvent;
+import org.mule.DefaultMuleMessage;
+import org.mule.MessageExchangePattern;
+import org.mule.VoidMuleEvent;
+import org.mule.api.MessagingException;
 import org.mule.api.MuleEvent;
-import org.mule.api.MuleRuntimeException;
-import org.mule.api.NamedObject;
+import org.mule.api.NameableObject;
 import org.mule.api.construct.FlowConstruct;
 import org.mule.api.context.notification.BlockingServerEvent;
 import org.mule.api.context.notification.ServerNotification;
 import org.mule.api.processor.MessageProcessor;
+import org.mule.transport.NullPayload;
 import org.mule.util.ObjectUtils;
 
-import java.lang.reflect.Method;
-
 public class MessageProcessorNotification extends ServerNotification implements BlockingServerEvent
 {
 
@@ -30,7 +33,6 @@ public class MessageProcessorNotification extends ServerNotification implements
     public static final int MESSAGE_PROCESSOR_POST_INVOKE = MESSAGE_PROCESSOR_EVENT_ACTION_START_RANGE + 2;
 
     private final transient MessageProcessor processor;
-    private String messageProcessorName;
 
     static
     {
@@ -38,34 +40,17 @@ public class MessageProcessorNotification extends ServerNotification implements
         registerAction("message processor post invoke", MESSAGE_PROCESSOR_POST_INVOKE);
     }
 
+    private static ThreadLocal<String> lastRootMessageId = new ThreadLocal<String>();
+    private MessagingException exceptionThrown;
 
-    public MessageProcessorNotification(FlowConstruct flowConstruct, MuleEvent event, MessageProcessor processor, int action)
+    public MessageProcessorNotification(FlowConstruct flowConstruct,
+                                        MuleEvent event,
+                                        MessageProcessor processor,
+                                        MessagingException exceptionThrown, int action)
     {
-        super(event, action, flowConstruct != null ? flowConstruct.getName() : null);
-
+        super(produceEvent(event, flowConstruct), action, flowConstruct != null ? flowConstruct.getName() : null);
+        this.exceptionThrown = exceptionThrown;
         this.processor = processor;
-
-        // can't extract it to a method and still kepp the field final, have to leave it inline
-        try
-        {
-            // TODO would love to see MP.getName() in the API. Avoid BeanUtils.getProperty() overhead here
-            
-            try
-            {
-                final Method method = processor.getClass().getMethod("getName");
-                // invoke existing getName(), but provide same fallback if it returned nothing
-                messageProcessorName = ObjectUtils.toString(method.invoke(processor), toString(processor));
-            }
-            catch (NoSuchMethodException e)
-            {
-                // no such method, fallback to MP class name + NamedObject
-                messageProcessorName = toString(processor);
-            }
-        }
-        catch (Exception e)
-        {
-            throw new MuleRuntimeException(e);
-        }
     }
 
     @Override
@@ -83,11 +68,6 @@ public class MessageProcessorNotification extends ServerNotification implements
         return processor;
     }
 
-    public String getFriendlyProcessorName()
-    {
-        return messageProcessorName;
-    }
-
     protected String toString(Object obj)
     {
         if (obj == null)
@@ -96,9 +76,9 @@ public class MessageProcessorNotification extends ServerNotification implements
         }
 
         String name;
-        if (obj instanceof NamedObject)
+        if (obj instanceof NameableObject)
         {
-            name = String.format("%s '%s'", obj.getClass().getName(), ((NamedObject) obj).getName());
+            name = String.format("%s '%s'", obj.getClass().getName(), ((NameableObject) obj).getName());
         }
         else
         {
@@ -106,4 +86,33 @@ public class MessageProcessorNotification extends ServerNotification implements
         }
         return name;
     }
+
+    /**
+     * If event is null, produce and event with the proper message root ID, to allow it to be correlated
+     * with others in the thread
+     */
+    private static MuleEvent produceEvent(MuleEvent sourceEvent, FlowConstruct flowConstruct)
+    {
+        String rootId = lastRootMessageId.get();
+        if (sourceEvent != null && !VoidMuleEvent.getInstance().equals(sourceEvent))
+        {
+            lastRootMessageId.set(sourceEvent.getMessage().getMessageRootId());
+            return sourceEvent;
+        }
+        else if (rootId != null && flowConstruct != null)
+        {
+            DefaultMuleMessage msg = new DefaultMuleMessage(NullPayload.getInstance(), flowConstruct.getMuleContext());
+            msg.setMessageRootId(rootId);
+            return new DefaultMuleEvent(msg, MessageExchangePattern.REQUEST_RESPONSE, flowConstruct);
+        }
+        else
+        {
+            return null;
+        }
+    }
+
+    public MessagingException getExceptionThrown()
+    {
+        return exceptionThrown;
+    }
 }
