@@ -1,5 +1,5 @@
 /*
- * $Id: DefaultInboundEndpoint.java 21272 2011-02-14 22:08:21Z tcarlson $
+ * $Id: DefaultInboundEndpoint.java 24079 2012-03-15 15:46:31Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -20,6 +20,8 @@ import org.mule.api.context.MuleContextAware;
 import org.mule.api.endpoint.EndpointMessageProcessorChainFactory;
 import org.mule.api.endpoint.EndpointURI;
 import org.mule.api.endpoint.InboundEndpoint;
+import org.mule.api.exception.MessagingExceptionHandler;
+import org.mule.api.exception.MessagingExceptionHandlerAcceptor;
 import org.mule.api.lifecycle.Initialisable;
 import org.mule.api.lifecycle.LifecycleException;
 import org.mule.api.lifecycle.Startable;
@@ -30,6 +32,9 @@ import org.mule.api.transaction.TransactionConfig;
 import org.mule.api.transport.Connector;
 import org.mule.config.MuleManifest;
 import org.mule.config.i18n.CoreMessages;
+import org.mule.exception.ChoiceMessagingExceptionStrategy;
+import org.mule.exception.RollbackMessagingExceptionStrategy;
+import org.mule.processor.AbstractRedeliveryPolicy;
 import org.mule.transport.ConnectException;
 import org.mule.transport.polling.MessageProcessorPollingMessageReceiver;
 
@@ -57,6 +62,7 @@ public class DefaultInboundEndpoint extends AbstractEndpoint implements InboundE
                                   String endpointBuilderName,
                                   MuleContext muleContext,
                                   RetryPolicyTemplate retryPolicyTemplate,
+                                  AbstractRedeliveryPolicy redeliveryPolicy,
                                   EndpointMessageProcessorChainFactory messageProcessorsFactory,
                                   List <MessageProcessor> messageProcessors,
                                   List <MessageProcessor> responseMessageProcessors,
@@ -66,7 +72,7 @@ public class DefaultInboundEndpoint extends AbstractEndpoint implements InboundE
         super(connector, endpointUri, name, properties, 
             transactionConfig, deleteUnacceptedMessage,
             messageExchangePattern, responseTimeout, initialState, endpointEncoding, 
-            endpointBuilderName, muleContext, retryPolicyTemplate,  messageProcessorsFactory, 
+            endpointBuilderName, muleContext, retryPolicyTemplate, redeliveryPolicy, messageProcessorsFactory,
             messageProcessors, responseMessageProcessors, disableTransportTransformer,
             mimeType);
     }
@@ -209,4 +215,57 @@ public class DefaultInboundEndpoint extends AbstractEndpoint implements InboundE
         // services get mixed up after deserialization of events
         return System.identityHashCode(this);
     }
+
+    @Override
+    public AbstractRedeliveryPolicy getRedeliveryPolicy()
+    {
+        /*TODO Next commit will fix this horrible thing:
+         inbound endpoint should only be aware of a redelivery policy configured on it
+         flowConstruct should be responsible of redelivery policy use */
+        AbstractRedeliveryPolicy redeliveryPolicy = super.getRedeliveryPolicy();
+        RollbackMessagingExceptionStrategy rollbackMessagingExceptionStrategy = null;
+        if (flowConstruct != null && flowConstruct.getExceptionListener() != null)
+        {
+            MessagingExceptionHandler exceptionListener = flowConstruct.getExceptionListener();
+            if (exceptionListener instanceof RollbackMessagingExceptionStrategy)
+            {
+                rollbackMessagingExceptionStrategy = (RollbackMessagingExceptionStrategy) exceptionListener;
+            }
+            else if (exceptionListener instanceof ChoiceMessagingExceptionStrategy)
+            {
+                ChoiceMessagingExceptionStrategy choiceMessagingExceptionStrategy = (ChoiceMessagingExceptionStrategy) exceptionListener;
+                for (MessagingExceptionHandlerAcceptor messagingExceptionHandlerAcceptor : choiceMessagingExceptionStrategy.getExceptionListeners())
+                {
+                    if (messagingExceptionHandlerAcceptor instanceof RollbackMessagingExceptionStrategy && ((RollbackMessagingExceptionStrategy) messagingExceptionHandlerAcceptor).hasMaxRedeliveryAttempts())
+                    {
+                        rollbackMessagingExceptionStrategy = (RollbackMessagingExceptionStrategy) messagingExceptionHandlerAcceptor;
+                        break;
+                    }
+                }
+            }
+        }
+        if (rollbackMessagingExceptionStrategy != null && rollbackMessagingExceptionStrategy.hasMaxRedeliveryAttempts())
+        {
+            if (redeliveryPolicy == null)
+            {
+                redeliveryPolicy = createDefaultRedeliveryPolicy(rollbackMessagingExceptionStrategy.getMaxRedeliveryAttempts());
+            }
+            else
+            {
+                redeliveryPolicy.setMaxRedeliveryCount(rollbackMessagingExceptionStrategy.getMaxRedeliveryAttempts());
+            }
+        }
+        return redeliveryPolicy;
+    }
+
+    @Override
+    public AbstractRedeliveryPolicy createDefaultRedeliveryPolicy(int maxRedelivery)
+    {
+        return getConnector().createDefaultRedeliveryPolicy(maxRedelivery);
+    }
+    
+    public FlowConstruct getFlowConstruct()
+    {
+        return flowConstruct;
+    }
 }
