@@ -1,5 +1,5 @@
 /*
- * $Id: DynamicOutboundEndpoint.java 22870 2011-09-05 20:41:52Z dfeist $
+ * $Id: DynamicOutboundEndpoint.java 23599 2012-01-11 01:28:48Z pablo.kraan $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,6 +12,7 @@ package org.mule.endpoint;
 
 import org.mule.DefaultMuleEvent;
 import org.mule.MessageExchangePattern;
+import org.mule.ResponseOutputStream;
 import org.mule.api.MuleContext;
 import org.mule.api.MuleEvent;
 import org.mule.api.MuleException;
@@ -34,13 +35,13 @@ import org.mule.api.transformer.Transformer;
 import org.mule.api.transport.Connector;
 import org.mule.api.transport.DispatchException;
 import org.mule.config.i18n.CoreMessages;
+import org.mule.processor.AbstractRedeliveryPolicy;
 
 import java.util.List;
 import java.util.Map;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.mule.processor.AbstractRedeliveryPolicy;
 
 /**
  * An Outbound endpoint who's URI is a template used to created new non dynamic
@@ -139,7 +140,10 @@ public class DynamicOutboundEndpoint implements OutboundEndpoint
         EndpointURI endpointURIForMessage = getEndpointURIForMessage(event);
         OutboundEndpoint outboundEndpoint = createStaticEndpoint(endpointURIForMessage);
 
-        event = new DefaultMuleEvent(event.getMessage(), endpointURIForMessage.getUri(), event.getExchangePattern(), event.getSession());
+        event = new DefaultMuleEvent(event.getMessage(), endpointURIForMessage.getUri(), event.getMessageSourceName(),
+                                     event.getExchangePattern(), event.getFlowConstruct(), event.getSession(), event.getTimeout(),
+                                     event.getCredentials(), (ResponseOutputStream) event.getOutputStream(), event.getEncoding(),
+                                     event.isTransacted(), event.isSynchronous(), event.getReplyToDestination(), event.getReplyToHandler());
 
         return outboundEndpoint.process(event);
     }
