@@ -1,5 +1,5 @@
 /*
- * $Id: URIBuilder.java 22566 2011-07-27 22:52:53Z julien.eluard $
+ * $Id: URIBuilder.java 24359 2012-04-26 19:00:18Z evangelinamrm $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -50,7 +50,6 @@ import javax.xml.namespace.QName;
  */
 public class URIBuilder implements AnnotatedObject
 {
-
     private static final String DOTS = ":";
     private static final String DOTS_SLASHES = DOTS + "//";
     private static final String QUERY = "?";
@@ -83,7 +82,7 @@ public class URIBuilder implements AnnotatedObject
     private String user;
     private String password;
     private String host;
-    private Integer port;
+    private String port;
     private String path;
     private Map queryMap;
     private MuleContext muleContext;
@@ -156,10 +155,22 @@ public class URIBuilder implements AnnotatedObject
         assertAddressConsistent();
     }
 
+    /**
+     * For backwards compatibility
+     */
     public void setPort(int port)
     {
         assertNotUsed();
-        this.port = new Integer(port);
+        this.port = Integer.toString(port);
+    }
+
+    /**
+     * Allows ports to be Mule expressions
+     */
+    public void setPort(String port)
+    {
+        assertNotUsed();
+        this.port = port;
     }
 
     public void setProtocol(String protocol)
@@ -320,7 +331,7 @@ public class URIBuilder implements AnnotatedObject
         }
         if (null != path)
         {
-            if (! atStart)
+            if (!atStart && !path.startsWith("/"))
             {
                 buffer.append("/");
             }
