@@ -1,5 +1,5 @@
 /*
- * $Id: URIBuilderTestCase.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id: URIBuilderTestCase.java 24359 2012-04-26 19:00:18Z evangelinamrm $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,12 +10,19 @@
 
 package org.mule.endpoint;
 
+import org.mule.api.MuleContext;
 import org.mule.api.endpoint.EndpointURI;
-import org.mule.tck.AbstractMuleTestCase;
+import org.mule.tck.junit4.AbstractMuleTestCase;
+import org.mule.tck.size.SmallTest;
 
 import java.util.HashMap;
 import java.util.Map;
 
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
+
+@SmallTest
 public class URIBuilderTestCase extends AbstractMuleTestCase
 {
 
@@ -28,25 +35,30 @@ public class URIBuilderTestCase extends AbstractMuleTestCase
         queries.put("bname", "bvalue");
     }
 
+    protected MuleContext unusedMuleContext = null;
+    
+    @Test
     public void testAddressForProtocol()
     {
-        URIBuilder uri = new URIBuilder(muleContext);
+        URIBuilder uri = new URIBuilder(unusedMuleContext);
         uri.setProtocol("foo");
         uri.setAddress("foo://bar");
         assertEquals("foo://bar", uri.toString());
     }
 
+    @Test
     public void testAddressForMeta()
     {
-        URIBuilder uri = new URIBuilder(muleContext);
+        URIBuilder uri = new URIBuilder(unusedMuleContext);
         uri.setMeta("foo");
         uri.setAddress("baz://bar");
         assertEquals("foo:baz://bar", uri.toString());
     }
 
+    @Test
     public void testQueriesWithAddress()
     {
-        URIBuilder uri = new URIBuilder(muleContext);
+        URIBuilder uri = new URIBuilder(unusedMuleContext);
         uri.setAddress("foo://bar");
         uri.setQueryMap(queries);
         assertEquals("foo://bar?aname=avalue&bname=bvalue", uri.toString());
@@ -54,42 +66,46 @@ public class URIBuilderTestCase extends AbstractMuleTestCase
 
     // note that explicit properties over-rule those in the uri when duplicated
     // and we keep parameter ordering as in original url
+    @Test
     public void testLiteralQueries()
     {
-        URIBuilder uri1 = new URIBuilder(muleContext);
+        URIBuilder uri1 = new URIBuilder(unusedMuleContext);
         uri1.setAddress("foo://bar?cname=cvalue&aname=anothervalue");
         uri1.setQueryMap(queries);
         assertEquals("foo://bar?cname=cvalue&aname=avalue&bname=bvalue", uri1.toString());
-        URIBuilder uri2 = new URIBuilder(muleContext);
+        URIBuilder uri2 = new URIBuilder(unusedMuleContext);
         uri2.setQueryMap(queries);
         uri2.setAddress("foo://bar?cname=cvalue&aname=anothervalue");
         assertEquals("foo://bar?cname=cvalue&aname=avalue&bname=bvalue", uri2.toString());
     }
 
+    @Test
     public void testNullQueries()
     {
-        URIBuilder uri1 = new URIBuilder(muleContext);
+        URIBuilder uri1 = new URIBuilder(unusedMuleContext);
         uri1.setAddress("foo://bar?cname&aname");
         uri1.setQueryMap(queries);
         assertEquals("foo://bar?cname&aname=avalue&bname=bvalue", uri1.toString());
     }
 
+    @Test
     public void testFromString()
     {
-        URIBuilder uri = new URIBuilder("test://bar", muleContext);
+        URIBuilder uri = new URIBuilder("test://bar", unusedMuleContext);
         EndpointURI endpointURI = uri.getEndpoint();
         assertEquals("test://bar", endpointURI.getUri().toString());
         assertEquals("test", endpointURI.getSchemeMetaInfo());
-        uri = new URIBuilder("meta:test://bar", muleContext);
+        uri = new URIBuilder("meta:test://bar", unusedMuleContext);
         endpointURI = uri.getEndpoint();
         assertEquals("test://bar", endpointURI.getUri().toString());
         assertEquals("meta", endpointURI.getSchemeMetaInfo());
     }
 
+    @Test
     public void testMultiValueParam() 
     {
         // Test from uri string
-        URIBuilder uri = new URIBuilder("test://bar?aname=avalue&aname=bvalue&aname=cvalue", muleContext);
+        URIBuilder uri = new URIBuilder("test://bar?aname=avalue&aname=bvalue&aname=cvalue", unusedMuleContext);
         EndpointURI endpointURI = uri.getEndpoint();
         assertEquals("test://bar?aname=avalue&aname=bvalue&aname=cvalue", endpointURI.getUri().toString());
 
@@ -98,10 +114,24 @@ public class URIBuilderTestCase extends AbstractMuleTestCase
         tq.put("aname", "zvalue");
         tq.put("dname", "dvalue");
 
-        uri = new URIBuilder("test://bar?aname=avalue&aname=bvalue&aname=cvalue", muleContext);
+        uri = new URIBuilder("test://bar?aname=avalue&aname=bvalue&aname=cvalue", unusedMuleContext);
         uri.setQueryMap(tq);
         endpointURI = uri.getEndpoint();
         assertEquals("test://bar?aname=zvalue&aname=bvalue&aname=cvalue&dname=dvalue", endpointURI.getUri().toString());
     }
-    
+
+    @Test
+    public void testConstructAddress()
+    {
+        URIBuilder uri = new URIBuilder();
+        uri.setHost("localhost");
+        uri.setPort(8080);
+        uri.setProtocol("http");
+        uri.setPath("/test");
+
+        String result = uri.getEncodedConstructor();
+        assertEquals("http://localhost:8080/test", result);
+    }
+
+
 }
