@@ -1,5 +1,5 @@
 /*
- * $Id: InboundNotificationMessageProcessor.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: InboundNotificationMessageProcessor.java 22609 2011-08-08 17:58:59Z julien.eluard $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -11,15 +11,17 @@
 package org.mule.endpoint.inbound;
 
 import org.mule.api.MuleEvent;
+import org.mule.api.MuleException;
 import org.mule.api.endpoint.InboundEndpoint;
+import org.mule.api.processor.MessageProcessor;
 import org.mule.context.notification.EndpointMessageNotification;
-import org.mule.processor.AbstractMessageObserver;
 import org.mule.transport.AbstractConnector;
+import org.mule.util.ObjectUtils;
 
 /**
  * Publishes a {@link EndpointMessageNotification}'s when a message is received.
  */
-public class InboundNotificationMessageProcessor extends AbstractMessageObserver
+public class InboundNotificationMessageProcessor implements MessageProcessor
 {
     protected InboundEndpoint endpoint;
 
@@ -28,14 +30,29 @@ public class InboundNotificationMessageProcessor extends AbstractMessageObserver
         this.endpoint = endpoint;
     }
 
-    @Override
-    public void observe(MuleEvent event)
+    public MuleEvent process(MuleEvent event) throws MuleException
     {
         AbstractConnector connector = (AbstractConnector) endpoint.getConnector();
         if (connector.isEnableMessageEvents())
         {
             connector.fireNotification(new EndpointMessageNotification(event.getMessage(), endpoint,
-                event.getFlowConstruct().getName(), EndpointMessageNotification.MESSAGE_RECEIVED));
+                event.getFlowConstruct(), EndpointMessageNotification.MESSAGE_RECEIVED));
         }
+
+        return event;
+    }
+
+    /**
+     * @return underlying {@link InboundEndpoint}
+     */
+    public final InboundEndpoint getInboundEndpoint()
+    {
+        return this.endpoint;
+    }
+
+    @Override
+    public String toString()
+    {
+        return ObjectUtils.toString(this);
     }
 }
