@@ -1,5 +1,5 @@
 /*
- * $Id: MessageEnricher.java 20759 2010-12-15 23:30:56Z dfeist $
+ * $Id: MessageEnricher.java 24450 2012-05-29 19:39:09Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSource, Inc.  All rights reserved.  http://www.mulesource.com
  *
@@ -10,7 +10,9 @@
 
 package org.mule.enricher;
 
-import org.mule.RequestContext;
+import org.mule.DefaultMuleEvent;
+import org.mule.OptimizedRequestContext;
+import org.mule.VoidMuleEvent;
 import org.mule.api.MuleEvent;
 import org.mule.api.MuleException;
 import org.mule.api.MuleMessage;
@@ -23,6 +25,32 @@ import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
 
+/**
+ * The <code>Message Enricher</code> allows the current message to be augmented using data from a seperate
+ * resource.
+ * <p>
+ * The Mule implementation the <i>Enrichment Resource</i> can be any Message Processor. This allows you to not
+ * only use a JDBC endpoint directly but also call out to a remote service via HTTP or even reference another
+ * flow or sub-flow.
+ * <p>
+ * The Message Processor that implements the <i>Enrichment Resource</i> is invoked with a copy of the current
+ * message along with any flow or session variables that are present. Invocation of the this message processor
+ * is done in a separate context to the main flow such that any modification to the message (and it's
+ * properties and attachments) or flow or session variables will not be reflected in the flow where the
+ * enricher is configured.
+ * <p>
+ * The <i>Enrichment Resource</i> should always return a result. If it doesn't then the Enricher will simply
+ * leave the message untouched.
+ * <p>
+ * The way in which the message is enriched (or modified) is by explicitly configuring mappings (source ->
+ * target) between the result from the Enrichment Resource and the message using of Mule Expressions. Mule
+ * Expressions are used to both select the value to be extracted from result that comes back from the
+ * enrichment resource (source) and to define where this value to be inserted into the message (target). The
+ * default 'source' if it's not configured is the payload of the result from the enrichment resource..
+ * <p>
+ * <b>EIP Reference:</b> <a
+ * href="http://eaipatterns.com/DataEnricher.html">http://eaipatterns.com/DataEnricher.html<a/>
+ */
 public class MessageEnricher extends AbstractMessageProcessorOwner implements MessageProcessor
 {
 
@@ -33,17 +61,30 @@ public class MessageEnricher extends AbstractMessageProcessorOwner implements Me
     public MuleEvent process(MuleEvent event) throws MuleException
     {
         ExpressionManager expressionManager = event.getMuleContext().getExpressionManager();
-        MuleMessage enrichmentMessage = enrichmentProcessor.process(RequestContext.setEvent(event))
-            .getMessage();
 
-        if (enrichmentMessage != null)
+        MuleEvent enricherEvent;
+        enricherEvent = DefaultMuleEvent.copy(event);
+
+        OptimizedRequestContext.unsafeSetEvent(enricherEvent);
+        MuleEvent enrichmentEvent = enrichmentProcessor.process(enricherEvent);
+        OptimizedRequestContext.unsafeSetEvent(event);
+
+        if (enrichmentEvent != null && !VoidMuleEvent.getInstance().equals(enrichmentEvent))
         {
             for (EnrichExpressionPair pair : enrichExpressionPairs)
             {
-                enrich(event.getMessage(), enrichmentMessage, pair.getSource(), pair.getTarget(),
+                enrich(event.getMessage(), enrichmentEvent.getMessage(), pair.getSource(), pair.getTarget(),
                     expressionManager);
             }
         }
+
+        if (muleContext != null
+            && muleContext.getConfiguration().isEnricherPropagatesSessionVariableChanges())
+        {
+            event = new DefaultMuleEvent(event.getMessage(), event, enrichmentEvent.getSession());
+        }
+        OptimizedRequestContext.unsafeSetEvent(event);
+
         return event;
     }
 
@@ -55,7 +96,7 @@ public class MessageEnricher extends AbstractMessageProcessorOwner implements Me
     {
         if (StringUtils.isEmpty(sourceExpressionArg))
         {
-            sourceExpressionArg = "#[payload]";
+            sourceExpressionArg = "#[payload:]";
         }
 
         Object enrichmentObject = expressionManager.evaluate(sourceExpressionArg, enrichmentMessage);
