@@ -1,5 +1,5 @@
 /*
- * $Id: AbstractMessagingExceptionStrategy.java 22772 2011-08-27 15:20:15Z dfeist $
+ * $Id: AbstractMessagingExceptionStrategy.java 23768 2012-01-31 16:08:45Z pablo.lagreca $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -17,7 +17,6 @@ import org.mule.api.MuleEvent;
 import org.mule.api.MuleException;
 import org.mule.api.construct.FlowConstruct;
 import org.mule.api.exception.MessagingExceptionHandler;
-import org.mule.api.exception.RollbackSourceCallback;
 import org.mule.api.lifecycle.Lifecycle;
 import org.mule.api.lifecycle.Stoppable;
 import org.mule.management.stats.FlowConstructStatistics;
@@ -28,19 +27,23 @@ import org.mule.transport.NullPayload;
  * Fire a notification, log exception, increment statistics, route the problematic message to a destination 
  * if one is configured (DLQ pattern), commit or rollback transaction if one exists, close any open streams.
  */
-public abstract class AbstractMessagingExceptionStrategy extends AbstractExceptionStrategy implements MessagingExceptionHandler
+public abstract class AbstractMessagingExceptionStrategy extends AbstractExceptionListener implements MessagingExceptionHandler
 {
     /** 
      * Stop the flow/service when an exception occurs.  You will need to restart the flow/service manually after this (e.g, using JMX). 
      */
     private boolean stopMessageProcessing;
 
-    public AbstractMessagingExceptionStrategy(MuleContext muleContext)
+    public AbstractMessagingExceptionStrategy()
     {
-        super(muleContext);
     }
 
-    public MuleEvent handleException(Exception ex, MuleEvent event, RollbackSourceCallback rollbackMethod)
+    public AbstractMessagingExceptionStrategy(MuleContext muleContext)
+    {
+        setMuleContext(muleContext);
+    }
+
+    public MuleEvent handleException(Exception ex, MuleEvent event)
     {
         fireNotification(ex);
 
@@ -49,7 +52,7 @@ public abstract class AbstractMessagingExceptionStrategy extends AbstractExcepti
 
         logException(ex);
         
-        doHandleException(ex, event, rollbackMethod);
+        doHandleException(ex, event);
 
         ExceptionPayload exceptionPayload = new DefaultExceptionPayload(ex);
         if (RequestContext.getEvent() != null)
@@ -60,13 +63,8 @@ public abstract class AbstractMessagingExceptionStrategy extends AbstractExcepti
         event.getMessage().setExceptionPayload(exceptionPayload);
         return event;
     }
-    
-    public MuleEvent handleException(Exception ex, MuleEvent event)
-    {
-        return handleException(ex, event, null);
-    }
-    
-    protected void doHandleException(Exception ex, MuleEvent event, RollbackSourceCallback rollbackMethod)
+
+    protected void doHandleException(Exception ex, MuleEvent event)
     {
         FlowConstructStatistics statistics = event.getFlowConstruct().getStatistics();
         if (statistics != null && statistics.isEnabled())
@@ -74,24 +72,24 @@ public abstract class AbstractMessagingExceptionStrategy extends AbstractExcepti
             statistics.incExecutionError();
         }
 
+        // Left this here for backwards-compatibility, remove in the next major version.
+        defaultHandler(ex);
+
         if (isRollback(ex))
         {
             logger.debug("Rolling back transaction");
-            rollback(rollbackMethod);
+            rollback(ex);
 
             logger.debug("Routing exception message");
-            routeException(event, ex);
+            routeException(event, null, ex);
         }
         else
         {
             logger.debug("Routing exception message");
-            routeException(event, ex);
-            
-            logger.debug("Committing transaction");
-            commit();
+            routeException(event, null, ex);
         }
 
-        closeStream(event.getMessage());        
+        closeStream(event.getMessage());
 
         if (stopMessageProcessing)
         {
@@ -129,4 +127,13 @@ public abstract class AbstractMessagingExceptionStrategy extends AbstractExcepti
     {
         this.stopMessageProcessing = stopMessageProcessing;
     }
+
+    /**
+     * @deprecated Override doHandleException(Exception e, MuleEvent event) instead
+     */
+    // Left this here for backwards-compatibility, remove in the next major version.
+    protected void defaultHandler(Throwable t)
+    {
+        // empty
+    }
 }
