@@ -1,5 +1,5 @@
 /*
- * $Id: RegistryExpressionEvaluator.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: RegistryExpressionEvaluator.java 23782 2012-02-01 17:26:38Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -140,11 +140,4 @@ public class RegistryExpressionEvaluator implements ExpressionEvaluator, MuleCon
         return NAME;
     }
 
-    /**
-     * {@inheritDoc}
-     */
-    public void setName(String name)
-    {
-        throw new UnsupportedOperationException();
-    }
 }
