@@ -1,5 +1,5 @@
 /*
- * $Id: StringExpressionEvaluator.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id: StringExpressionEvaluator.java 23782 2012-02-01 17:26:38Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -43,13 +43,4 @@ public class StringExpressionEvaluator implements ExpressionEvaluator, MuleConte
         return NAME;
     }
 
-    /**
-     * Sets the name of the object
-     *
-     * @param name the name of the object
-     */
-    public void setName(String name)
-    {
-        throw new UnsupportedOperationException();
-    }
 }
