@@ -1,5 +1,5 @@
 /*
- * $Id: InterceptorTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: InterceptorTestCase.java 22377 2011-07-11 12:41:42Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -11,15 +11,22 @@
 package org.mule.interceptor;
 
 import org.mule.api.MuleEvent;
+import org.mule.api.MuleException;
 import org.mule.api.service.Service;
 import org.mule.component.AbstractComponent;
+import org.mule.management.stats.ProcessingTime;
 import org.mule.model.seda.SedaService;
-import org.mule.tck.AbstractMuleTestCase;
+import org.mule.tck.junit4.AbstractMuleContextTestCase;
 
 import java.util.ArrayList;
 import java.util.List;
 
-public class InterceptorTestCase extends AbstractMuleTestCase
+import org.junit.Test;
+
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.fail;
+
+public class InterceptorTestCase extends AbstractMuleContextTestCase
 {
 
     private final String BEFORE = "Before";
@@ -36,6 +43,7 @@ public class InterceptorTestCase extends AbstractMuleTestCase
                                                        + INTERCEPTOR_THREE + AFTER + INTERCEPTOR_TWO + AFTER
                                                        + INTERCEPTOR_ONE + AFTER;
 
+    @Test
     public void testSingleInterceptor() throws Exception
     {
         Service service = createUninitializedService();
@@ -47,11 +55,12 @@ public class InterceptorTestCase extends AbstractMuleTestCase
         service.initialise();
         service.start();
 
-        MuleEvent result = component.process(getTestInboundEvent(""));
+        MuleEvent result = component.process(getTestEvent(""));
 
         assertEquals(SINGLE_INTERCEPTOR_RESULT, result.getMessageAsString());
     }
 
+    @Test
     public void testMultipleInterceptor() throws Exception
     {
         Service service = createUninitializedService();
@@ -65,11 +74,12 @@ public class InterceptorTestCase extends AbstractMuleTestCase
         service.initialise();
         service.start();
 
-        MuleEvent result = component.process(getTestInboundEvent(""));
+        MuleEvent result = component.process(getTestEvent(""));
 
         assertEquals(MULTIPLE_INTERCEPTOR_RESULT, result.getMessageAsString());
     }
 
+    @Test
     public void testSingleInterceptorStack() throws Exception
     {
         Service service = createUninitializedService();
@@ -83,11 +93,12 @@ public class InterceptorTestCase extends AbstractMuleTestCase
         service.initialise();
         service.start();
 
-        MuleEvent result = component.process(getTestInboundEvent(""));
+        MuleEvent result = component.process(getTestEvent(""));
 
         assertEquals(SINGLE_INTERCEPTOR_RESULT, result.getMessageAsString());
     }
 
+    @Test
     public void testMultipleInterceptorStack() throws Exception
     {
         Service service = createUninitializedService();
@@ -103,11 +114,12 @@ public class InterceptorTestCase extends AbstractMuleTestCase
         service.initialise();
         service.start();
 
-        MuleEvent result = component.process(getTestInboundEvent(""));
+        MuleEvent result = component.process(getTestEvent(""));
 
         assertEquals(MULTIPLE_INTERCEPTOR_RESULT, result.getMessageAsString());
     }
 
+    @Test
     public void testMultipleInterceptorStack2() throws Exception
     {
         Service service = createUninitializedService();
@@ -126,7 +138,7 @@ public class InterceptorTestCase extends AbstractMuleTestCase
         service.initialise();
         service.start();
 
-        MuleEvent result = component.process(getTestInboundEvent(""));
+        MuleEvent result = component.process(getTestEvent(""));
 
         assertEquals(INTERCEPTOR_ONE + BEFORE + INTERCEPTOR_TWO + BEFORE + INTERCEPTOR_THREE + BEFORE
                      + INTERCEPTOR_ONE + BEFORE + INTERCEPTOR_TWO + BEFORE + INTERCEPTOR_THREE + BEFORE
@@ -174,6 +186,12 @@ public class InterceptorTestCase extends AbstractMuleTestCase
             }
             return event;
         }
+
+        @Override
+        public MuleEvent last(MuleEvent event, ProcessingTime time, long startTime, boolean exceptionWasThrown) throws MuleException
+        {
+            return event;
+        }
     }
 
     protected Service createUninitializedService() throws Exception
