@@ -1,5 +1,5 @@
 /*
- * $Id: ProcessIfStartedMessageProcessor.java 20320 2010-11-24 15:03:31Z dfeist $
+ * $Id: ProcessIfStartedMessageProcessor.java 22048 2011-05-31 14:39:03Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -11,7 +11,7 @@
 package org.mule.lifecycle.processor;
 
 import org.mule.api.MuleEvent;
-import org.mule.api.NamedObject;
+import org.mule.api.NameableObject;
 import org.mule.api.lifecycle.LifecycleException;
 import org.mule.api.lifecycle.LifecycleState;
 import org.mule.api.lifecycle.Startable;
@@ -44,9 +44,9 @@ public class ProcessIfStartedMessageProcessor extends AbstractFilteringMessagePr
 
     protected String getStartableName(Startable startableObject)
     {
-        if (startableObject instanceof NamedObject)
+        if (startableObject instanceof NameableObject)
         {
-            return ((NamedObject) startableObject).getName();
+            return ((NameableObject) startableObject).getName();
         }
         else
         {
