@@ -1,5 +1,5 @@
 /*
- * $Id: Log4jAgentTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: Log4jAgentTestCase.java 22387 2011-07-12 03:53:36Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -16,9 +16,11 @@ import org.mule.module.management.agent.Log4jAgent;
 import javax.management.ObjectName;
 
 import org.apache.log4j.jmx.HierarchyDynamicMBean;
+import org.junit.Test;
 
 public class Log4jAgentTestCase extends AbstractMuleJmxTestCase
 {
+    @Test
     public void testRedeploy() throws Exception
     {
         mBeanServer.registerMBean(new HierarchyDynamicMBean(),
