@@ -1,5 +1,5 @@
 /*
- * $Id: ManagementDefaultNoLog4jTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: ManagementDefaultNoLog4jTestCase.java 22401 2011-07-13 09:10:18Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -11,16 +11,23 @@
 package org.mule.management.config;
 
 import org.mule.api.agent.Agent;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.junit4.FunctionalTestCase;
+
+import org.junit.Test;
+
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
 
 public class ManagementDefaultNoLog4jTestCase extends FunctionalTestCase
 {
 
+    @Override
     protected String getConfigResources()
     {
         return "management-default-no-log4j-config.xml";
     }
 
+    @Test
     public void testDefaultJmxAgentConfig() throws Exception
     {
         Agent agent = muleContext.getRegistry().lookupAgent("jmx-agent");
