@@ -1,5 +1,5 @@
 /*
- * $Id: SedaServiceTestCase.java 22870 2011-09-05 20:41:52Z dfeist $
+ * $Id: SedaServiceTestCase.java 24442 2012-05-28 22:15:50Z pablo.kraan $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -16,7 +16,6 @@ import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
-
 import org.mule.MessageExchangePattern;
 import org.mule.api.MuleEventContext;
 import org.mule.api.config.MuleProperties;
@@ -24,7 +23,7 @@ import org.mule.api.config.ThreadingProfile;
 import org.mule.api.lifecycle.Callable;
 import org.mule.api.registry.RegistrationException;
 import org.mule.api.service.Service;
-import org.mule.api.store.ListableObjectStore;
+import org.mule.api.store.QueueStore;
 import org.mule.component.DefaultJavaComponent;
 import org.mule.component.SimpleCallableJavaComponent;
 import org.mule.config.ChainedThreadingProfile;
@@ -39,7 +38,6 @@ import java.io.Serializable;
 import java.util.concurrent.TimeUnit;
 
 import junit.framework.AssertionFailedError;
-
 import org.junit.Test;
 
 public class SedaServiceTestCase extends AbstractServiceTestCase
@@ -89,8 +87,8 @@ public class SedaServiceTestCase extends AbstractServiceTestCase
         muleContext.getRegistry().registerObject(MuleProperties.OBJECT_QUEUE_MANAGER,
             mockTransactionalQueueManager);
 
-        ListableObjectStore<Serializable> objectStore =
-            muleContext.getRegistry().lookupObject(MuleProperties.OBJECT_STORE_DEFAULT_PERSISTENT_NAME);
+        QueueStore<Serializable> objectStore =
+            muleContext.getRegistry().lookupObject(MuleProperties.QUEUE_STORE_DEFAULT_PERSISTENT_NAME);
         service.setQueueProfile(new QueueProfile(capacity, objectStore));
 
         try
