@@ -1,5 +1,5 @@
 /*
- * $Id: RootCustomerTest.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: RootCustomerTest.java 22401 2011-07-13 09:10:18Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -9,6 +9,8 @@
  */
 package org.mule.module.atom;
 
+import org.junit.Test;
+
 public class RootCustomerTest extends AbstractCustomerTest
 {
 
@@ -18,6 +20,7 @@ public class RootCustomerTest extends AbstractCustomerTest
         return "customer-conf.xml";
     }
 
+    @Test
     public void testCustomerProvider() throws Exception
     {
         testCustomerProvider("");
