@@ -1,5 +1,5 @@
 /*
- * $Id: FeedSplitter.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id: FeedSplitter.java 24217 2012-04-03 14:29:27Z pablo.lagreca $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -92,7 +92,7 @@ public class FeedSplitter extends AbstractSplitter
         }
         catch (TransformerException e)
         {
-            throw new MessagingException(e.getI18nMessage(), event, e);
+            throw new MessagingException(e.getI18nMessage(), event, e, this);
         }
     }
 
