@@ -1,5 +1,5 @@
 /*
- * $Id: Process.java 20385 2010-11-29 20:25:26Z dfeist $
+ * $Id: Process.java 24265 2012-04-16 06:54:00Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSource, Inc.  All rights reserved.  http://www.mulesource.com
  *
@@ -13,6 +13,7 @@ package org.mule.module.bpm;
 import org.mule.DefaultMuleEvent;
 import org.mule.DefaultMuleMessage;
 import org.mule.MessageExchangePattern;
+import org.mule.VoidMuleEvent;
 import org.mule.RequestContext;
 import org.mule.api.MuleContext;
 import org.mule.api.MuleEvent;
@@ -20,7 +21,7 @@ import org.mule.api.MuleException;
 import org.mule.api.MuleMessage;
 import org.mule.api.config.MuleProperties;
 import org.mule.api.construct.FlowConstruct;
-import org.mule.api.endpoint.EndpointBuilder;
+import org.mule.api.endpoint.EndpointCache;
 import org.mule.api.endpoint.OutboundEndpoint;
 import org.mule.api.lifecycle.Disposable;
 import org.mule.api.lifecycle.Initialisable;
@@ -28,7 +29,7 @@ import org.mule.api.lifecycle.InitialisationException;
 import org.mule.api.transport.DispatchException;
 import org.mule.api.transport.PropertyScope;
 import org.mule.config.i18n.MessageFactory;
-import org.mule.session.DefaultMuleSession;
+import org.mule.endpoint.SimpleEndpointCache;
 import org.mule.transport.NullPayload;
 import org.mule.util.StringUtils;
 
@@ -84,7 +85,9 @@ public class Process implements Initialisable, Disposable, MessageService
     public static final String PROCESS_VARIABLE_INCOMING_SOURCE = "incomingSource";
     public static final String PROCESS_VARIABLE_DATA = "data";
 
-    protected transient Log logger = LogFactory.getLog(getClass());
+    protected static final Log logger = LogFactory.getLog(Process.class);
+
+    private final EndpointCache endpointCache;
 
     public Process(BPMS bpms, String name, String resource, FlowConstruct flowConstruct, MuleContext muleContext)
     {
@@ -99,6 +102,7 @@ public class Process implements Initialisable, Disposable, MessageService
         this.processIdField = processIdField;
         this.flowConstruct = flowConstruct;
         this.muleContext = muleContext;
+        this.endpointCache = new SimpleEndpointCache(muleContext);
     }
 
     public void initialise() throws InitialisationException
@@ -125,14 +129,14 @@ public class Process implements Initialisable, Disposable, MessageService
         }
     }
 
-    protected Object processAction(MuleEvent event) throws Exception
+    protected Object handleEvent(MuleEvent event) throws Exception
     {
         // An object representing the new state of the process
         Object process;
 
         // Create a map of process variables based on the message properties.
         Map processVariables = new HashMap();
-        if (event != null)
+        if (event != null && !VoidMuleEvent.getInstance().equals(event))
         {
             populateProcessVariables(event, processVariables, PropertyScope.INVOCATION);
             populateProcessVariables(event, processVariables, PropertyScope.INBOUND);
@@ -256,6 +260,7 @@ public class Process implements Initialisable, Disposable, MessageService
         }
     }
 
+    // TODO This method should probably use the LocalMuleClient instead of re-inventing the wheel
     public MuleMessage generateMessage(String endpoint, Object payload, Map messageProperties, MessageExchangePattern exchangePattern) throws MuleException
     {
         MuleMessage message;
@@ -267,18 +272,15 @@ public class Process implements Initialisable, Disposable, MessageService
         {
             message = new DefaultMuleMessage(payload, muleContext);
         }
-        message.addProperties(messageProperties, PropertyScope.INBOUND);
+        message.addProperties(messageProperties, PropertyScope.OUTBOUND);
         message.addProperties(messageProperties, PropertyScope.INVOCATION);
 
-        //TODO should probably cache this
-        EndpointBuilder endpointBuilder = muleContext.getEndpointFactory().getEndpointBuilder(endpoint);
-        endpointBuilder.setExchangePattern(exchangePattern);
-        OutboundEndpoint ep = endpointBuilder.buildOutboundEndpoint();
-       
-        DefaultMuleEvent event = new DefaultMuleEvent(message, ep, new DefaultMuleSession(flowConstruct, muleContext));
+        // Use an endpoint cache to prevent memory leaks (see MULE-5422)
+        OutboundEndpoint ep = endpointCache.getOutboundEndpoint(endpoint, exchangePattern, null);
+        DefaultMuleEvent event = new DefaultMuleEvent(message, ep.getExchangePattern(), flowConstruct);
+        RequestContext.setEvent(event);
 
         // Set correlation properties in SESSION scope so that they get propagated to response messages.
-        RequestContext.setEvent(event);
         if (messageProperties.get(PROPERTY_PROCESS_TYPE) != null)
         {
             event.getMessage().setSessionProperty(PROPERTY_PROCESS_TYPE, messageProperties.get(PROPERTY_PROCESS_TYPE));
@@ -291,7 +293,7 @@ public class Process implements Initialisable, Disposable, MessageService
         MuleEvent resultEvent = ep.process(event);
         
         MuleMessage response = null;
-        if (resultEvent != null)
+        if (resultEvent != null && !VoidMuleEvent.getInstance().equals(resultEvent))
         {
             response = resultEvent.getMessage();
             if (response.getExceptionPayload() != null)
