@@ -1,5 +1,5 @@
 /*
- * $Id: RemoteDispatcherComponent.java 22445 2011-07-18 22:38:47Z dfeist $
+ * $Id: RemoteDispatcherComponent.java 24265 2012-04-16 06:54:00Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,6 +13,7 @@ package org.mule.module.client.remoting;
 import org.mule.DefaultMuleEvent;
 import org.mule.DefaultMuleMessage;
 import org.mule.MessageExchangePattern;
+import org.mule.VoidMuleEvent;
 import org.mule.RequestContext;
 import org.mule.api.DefaultMuleException;
 import org.mule.api.MuleContext;
@@ -20,7 +21,6 @@ import org.mule.api.MuleEvent;
 import org.mule.api.MuleEventContext;
 import org.mule.api.MuleException;
 import org.mule.api.MuleMessage;
-import org.mule.api.MuleSession;
 import org.mule.api.config.MuleProperties;
 import org.mule.api.construct.FlowConstruct;
 import org.mule.api.endpoint.EndpointBuilder;
@@ -45,7 +45,6 @@ import org.mule.model.seda.SedaService;
 import org.mule.module.client.i18n.ClientMessages;
 import org.mule.module.client.remoting.notification.RemoteDispatcherNotification;
 import org.mule.object.SingletonObjectFactory;
-import org.mule.session.DefaultMuleSession;
 import org.mule.transport.AbstractConnector;
 import org.mule.transport.NullPayload;
 import org.mule.util.MapUtils;
@@ -181,22 +180,24 @@ public class RemoteDispatcherComponent implements Callable, Initialisable
             {
                 return handleException(null, new DefaultMuleException(ClientMessages.noSuchFlowConstruct(destComponent)));
             }
-            MuleSession session = new DefaultMuleSession((FlowConstruct) flowConstruct, muleContext);
+
             // Need to do this otherise when the event is invoked the
             // transformer associated with the Mule Admin queue will be invoked, but
             // the message will not be of expected type
-
             EndpointBuilder builder = new EndpointURIEndpointBuilder(inboundEndpoint);
             // TODO - is this correct? it stops any other transformer from being set
             builder.setTransformers(new LinkedList());
             InboundEndpoint ep = muleContext.getEndpointFactory().getInboundEndpoint(builder);
-            MuleEvent event = new DefaultMuleEvent(action.getMessage(), ep, context.getSession());
+            MuleEvent event = new DefaultMuleEvent(action.getMessage(), ep, context.getFlowConstruct(),
+                context.getSession());
             event = RequestContext.setEvent(event);
 
             if (context.getExchangePattern().hasResponse())
             {
                 MuleEvent resultEvent = ((MessageProcessor) flowConstruct).process(event);
-                result = resultEvent == null ? null : resultEvent.getMessage();
+                result = resultEvent == null || VoidMuleEvent.getInstance().equals(resultEvent)
+                                                                                               ? null
+                                                                                               : resultEvent.getMessage();
                 if (result == null)
                 {
                     return null;
@@ -244,7 +245,7 @@ public class RemoteDispatcherComponent implements Callable, Initialisable
 
                 endpoint = managementContext.getEndpointFactory().getOutboundEndpoint(endpointBuilder);
                 result = context.sendEvent(action.getMessage(), endpoint);
-                if (result == null)
+                if (result == null || VoidMuleEvent.getInstance().equals(result))
                 {
                     return null;
                 }
@@ -346,7 +347,7 @@ public class RemoteDispatcherComponent implements Callable, Initialisable
     protected Object handleException(MuleMessage result, Throwable e)
     {
         logger.error("Failed to process admin request: " + e.getMessage(), e);
-        if (result == null)
+        if (result == null || VoidMuleEvent.getInstance().equals(result))
         {
             result = new DefaultMuleMessage(NullPayload.getInstance(), (Map) null, muleContext);
         }
