@@ -1,5 +1,5 @@
 /*
- * $Id: Http10TestCase.java 21151 2011-01-31 21:53:23Z dzapata $
+ * $Id: Http10TestCase.java 22923 2011-09-12 21:13:21Z pablo.kraan $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,21 +10,46 @@
 
 package org.mule.module.cxf;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+
 import org.mule.api.MuleMessage;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.DynamicPortTestCase;
+import org.mule.tck.AbstractServiceAndFlowTestCase;
+import org.mule.tck.junit4.rule.DynamicPort;
 import org.mule.transport.http.HttpConstants;
 
+import java.util.Arrays;
+import java.util.Collection;
 import java.util.HashMap;
 import java.util.Map;
 
-public class Http10TestCase extends DynamicPortTestCase
+import org.junit.ClassRule;
+import org.junit.Test;
+import org.junit.runners.Parameterized.Parameters;
+
+public class Http10TestCase extends AbstractServiceAndFlowTestCase
 {
-    public Http10TestCase()
+
+    @ClassRule
+    public static DynamicPort dynamicPort = new DynamicPort("port1");
+
+    public Http10TestCase(ConfigVariant variant, String configResources)
     {
-        setDisposeManagerPerSuite(true);
+        super(variant, configResources);
+        setDisposeContextPerClass(true);
     }
 
+    @Parameters
+    public static Collection<Object[]> parameters()
+    {
+        return Arrays.asList(new Object[][]{
+            {ConfigVariant.SERVICE, "http-10-conf-service.xml"},
+            {ConfigVariant.FLOW, "http-10-conf-flow.xml"}
+        });
+    }      
+
+    @Test
     public void testHttp10TransformerNotOnProtocol() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -37,6 +62,7 @@ public class Http10TestCase extends DynamicPortTestCase
         assertFalse("chunked".equals(result.getOutboundProperty(HttpConstants.HEADER_TRANSFER_ENCODING)));
     }
 
+    @Test
     public void testHttp10TransformerOnProtocol() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
@@ -48,15 +74,4 @@ public class Http10TestCase extends DynamicPortTestCase
         result = client.request("vm://out", 1000);
         assertFalse("chunked".equals(result.getOutboundProperty(HttpConstants.HEADER_TRANSFER_ENCODING)));
     }
-
-    protected String getConfigResources()
-    {
-        return "http-10-conf.xml";
-    }
-
-    @Override
-    protected int getNumPortsToFind()
-    {
-        return 1;
-    }
 }
